/*global document, window, console, jQuery*/
/*jslint maxlen: 150, this: true*/
/*jshint esversion:6*/

(function ($) {
    "use strict";

    $.extend({
        simpleSlideToUnlock: function () {
            /* Private */
            var id_form, //Id of the form, which is used when the validation system is activated
                class_g, //Class used in the goal
                class_s, //Class applied to the object that is slidable
                class_sl, //Class of the global container
                class_w, //Class of the area in which the slider will move
                class_n, //Class of the area in which a status text will be displayed according to the slider
                class_ok, //Class to use when the skimmer reaches the finish line and meets the validations
                goal_co, //Value used to make corrections in the position of the goal
                drag_obj, //Sliding object
                form_obj, //Form object
                slid_obj, //Global object
                goal_obj, //Goal object
                note_obj, //Note object
                well_obj, //Well object
                goal_left, //Position of the draggable object with respect to its left
                w_goal, //Width of the goal
                message_send, //Message used to invite the user to make the slip
                message_ok, //Message used when the slider is released at the goal
                boxLeft, //Position of the draggable object with respect to its left
                startX, //Starting position of the sliding object
                distX, //Stores the distance the slider must travel so that it can return to its initial position.
                left_e, //Prevents the slider from leaving the action area
                success, //Variable propagation success
                back, //On/Off (true/false) return of slider
                obj_centinel = null,
                centinel = true,
                devolution = true,
                position_end = 0;

            /**
             * It allows to evaluate if the necessary libraries for the correct functioning
             * of the component are included
             */
            function dependence() {
                if ($.fn.exists.version < 20161121) {
                    console.warn("exists.js version 20161121 or higher");
                }

                if (!($.exists(typeof $.ui))) {
                    console.warn("jquery-ui.min.js is required");
                } else if (parseFloat($.ui.version) < 1.12) {
                    console.warn("jquery-ui-min.js version 1.12 or higher");
                }
            }

            /**
             * Eliminate all events and states that allow the slide to move
             */
            function destroy_draggable() {
                drag_obj.draggable("destroy");
                drag_obj.off("touchstart touchmove touchend");
            }

            /**
             * Determines the different processes to be performed when the slide reaches the goal
             */
            function sending() {
                devolution = back;
                success();
            }

            /**
             * Determines the existence of the elements necessary for the operation
             * of the slidetounlock
             *
             * @param {Object} obj Element to verify
             * @param {String} o_cen Object identifier
             */
            function comparison(obj, o_cen) {
                if (!obj.exists() && centinel) {
                    obj_centinel = o_cen;
                    centinel = false;
                }
            }

            /**
             * Calculate the place where the goal is located
             */
            function end_point() {
                w_goal = goal_obj.width() + goal_co;
                position_end = well_obj.width() - w_goal;
            }

            /**
             * Processes to be performed just when the object is started
             *
             * @param {Object} e event
             */
            function touch_start(e) {
                var evento = e.originalEvent;

                e.preventDefault();
                e.stopPropagation();

                boxLeft = parseFloat(drag_obj.css("left"));
                startX = parseFloat(evento.changedTouches[0].pageX);

                //Calculating the end point
                end_point();
            }

            /**
             * Processes to perform when the object is being dragged
             *
             * @param {Object} e event
             */
            function touch_move(e) {
                var evento = e.originalEvent;

                e.preventDefault();
                e.stopPropagation();

                distX = parseFloat(evento.changedTouches[0].pageX) - startX;
                left_e = (boxLeft + distX > position_end)
                    ? position_end
                    : (boxLeft + distX < 0)
                        ? 0
                        : boxLeft + distX;

                drag_obj.css({left: left_e + "px"});
            }

            /**
             * Processes to perform when the object is no longer dragged
             *
             * @param {Object} e event
             */
            function touch_end(e) {
                e.preventDefault();
                e.stopPropagation();

                //If it is not in the final position return the slider
                if (Math.floor(left_e) >= Math.floor(position_end)) {
                    sending();
                }

                if (left_e < position_end || devolution) {
                    drag_obj.animate({
                        left: "0px"
                    });
                } else {
                    note_obj.html(message_ok);
                    slid_obj.addClass(class_ok);
                }

                return devolution;
            }

            /**
             * It establishes the necessary properties so that the slide can initiate
             * its movement in an appropriate way
             */
            function move_slide() {
                //Initialization of variables for the move
                goal_left = 0;
                position_end = 0;
                devolution = true;

                //Browser
                drag_obj.draggable({
                    axis: "x",
                    containment: "parent",
                    revert: function () {
                        // Realization of validation when object is dragged to the goal
                        if (Math.floor(goal_left) >= Math.floor(position_end)) {
                            sending();
                        }

                        return devolution;
                    },
                    drag: function (e, ui) {
                        end_point();
                        goal_left = ui.position.left;
                        return e;
                    },
                    stop: function () {
                        if (!devolution) {
                            note_obj.html(message_ok);
                            slid_obj.addClass(class_ok);
                        }
                    }
                });

                //Touch
                if (drag_obj.dragabble === undefined) {
                    drag_obj.on("touchstart", touch_start.bind(drag_obj));
                    drag_obj.on("touchmove", touch_move.bind(drag_obj));
                    drag_obj.on("touchend", touch_end.bind(drag_obj));
                }
            }

            /**
             * Process to be performed at the time of initialization
             */
            function processing() {
                //Initialization of elements
                form_obj = $("#" + id_form);
                slid_obj = $("#" + id_form + " ." + class_sl);
                drag_obj = $("#" + id_form + " ." + class_sl + " ." + class_s);
                goal_obj = $("#" + id_form + " ." + class_sl + " ." + class_g);
                well_obj = $("#" + id_form + " ." + class_sl + " ." + class_w);
                note_obj = $("#" + id_form + " ." + class_sl + " ." + class_n);

                // Verifying the existence of the essential elements
                comparison(form_obj, "id_form");
                comparison(slid_obj, "class_sl");
                comparison(drag_obj, "class_s");
                comparison(goal_obj, "class_g");
                comparison(well_obj, "class_w");
                comparison(note_obj, "class_n");

                if (centinel) {
                    note_obj.html(message_send); //Change the slider message
                    move_slide(); //Start move
                } else {
                    console.warn("No exists some of the elements: " + obj_centinel);
                }
            }

            /* Public */
            return {
                /**
                 * Version of the script
                 */
                version: 20180412,

                /**
                 * Perform initialization processes and capture the attributes
                 * required of the slidetounlock
                 *
                 * @param {Object} attr_e Attributes of the slideTounlock
                 */
                init: function (attr_e) {
                    dependence();

                    var attr = attr_e || {};

                    id_form = attr.id_form || "form_1";
                    class_sl = attr.class_sl || "slidetounlock";
                    class_s = attr.class_s || "slider_unlock";
                    class_g = attr.class_g || "goal_unlock";
                    class_w = attr.class_w || "well";
                    class_n = attr.class_n || "slider_note";
                    goal_co = attr.goal_correction || 10;
                    class_ok = attr.class_ok || "ok";
                    message_send = attr.message_send || "Slide to send";
                    message_ok = attr.message_ok || "Sending";
                    back = attr.back || false;
                    success = attr.success || function () {
                        return undefined;
                    };

                    //Execute process
                    processing();
                },

                /**
                 * Allows you to restart the movement when it is already blocked
                 */
                reload_move: function () {
                    //Remove class_ok and message_ok
                    note_obj.html(message_send);
                    slid_obj.removeClass(class_ok);

                    //Browser
                    drag_obj.animate({left: "2px"});

                    //Start move
                    move_slide();
                },

                /**
                 * Eliminate slider movement
                 */
                destroy: function () {
                    destroy_draggable();
                }
            };
        }
    });
}(jQuery));
