<?php
/**
 * @file
 * Contains \Drupal\tigo_vtex_manage_orders\Controller\InvoiceTable
 */
namespace Drupal\transformation_activation\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\transformation_activation\ValidateActivation;
use Drupal\Core\Url;

class PreContrato extends ControllerBase
{

    public function View() {

        if(!isset($_SESSION['data_pospago'])){
            if(isset($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['SERVER_NAME']){
                $base_url = $_SERVER['HTTP_X_FORWARDED_PROTO'] . '://' . $_SERVER['SERVER_NAME'];
            }else{
                global $base_url;
            }
            header('Location: '.$base_url . '/servicios/activate');
            exit;
        }
        $validate = ValidateActivation::buildValidate();
        if($validate){
            return $validate;
        }

        ValidateActivation::validateMail();

        $form = \Drupal::formBuilder()->getForm(
            'Drupal\transformation_activation\Form\Anexos'
        );
        $info = $_SESSION['data_pospago'];
        $return = FALSE;
        $link_return = [
            '#type' => 'link',
            '#title' => 'Regresar',
            '#url' => Url::fromRoute('transformation_activation.package_service'),
            '#attributes' => [
                'class' => [
                    'link-return'
                ]
            ]
        ];
        if(isset($info['moreData']['real_order_id'])){
            $more_info = $this->queryData($info['moreData']['real_order_id']);
            if(isset($info['productId'])){
                $query = db_select('vtex_packages', 'vp');
                $query->addField('vp', 'plan_name');
                $query->addField('vp', 'plan_price');
                $query->addField('vp', 'plan_details');
                $query->condition('vp.vtex_plan_id', $info['productId'], '=');
                $result = $query->execute()->fetchObject();
                $fecha_inicio = strtotime('+1 day', time());
                $dia = format_date($fecha_inicio, 'custom', 'd');
                $fecha_inicio = format_date($fecha_inicio, 'custom', 'd/M/Y');
                if($result){
                    $detalles = json_decode($result->plan_details);
                    $details = [];
                    foreach ($detalles as $detalle){
                        $details[$detalle->tipo][] = [
                            'item' => $detalle->item,
                            'price' => $detalle->price
                        ];
                    }
                    $precio = number_format($result->plan_price, 0, '', '.');
                    $info['moreData']['precio'] = $precio;
                    $_SESSION['data_pospago'] = $info;
                    $return =  [
                        '#theme' => 'tigo-pre-contrato',
                        '#contrato' => $info['imsi'],
                        '#msisdn' => $this->numberFormatPhone($info['msisdn']),
                        '#fijo' => $more_info['client_phone'],
                        '#precio' => $precio,
                        '#movil_adicional' => $more_info['client_phone'],
                        '#ciudad' => $more_info['city'],
                        '#estado' => $more_info['state'],
                        '#nombre' => $info['moreData']['name'],
                        '#documento' => $info['docId'],
                        '#direccion' => $more_info['street'],
                        '#correo' => $info['moreData']['email'],
                        '#fecha_inicio' => $fecha_inicio,
                        '#dia' => $dia,
                        '#nombre_plan' => $result->plan_name,
                        '#form' => $form,
                        '#link_return' => $link_return,
                        '#detalles' => $details,
                        '#attached' => array(
                            'library' => array(
                                'transformation_activation/transformation_activation',
                                'tigo/tigo.scrollmove',
                                'tigo/tigo.retract'
                            )
                        )
                    ];
                }
            }
        }
        return $return;
    }

    public function numberFormatPhone($msisdn){
        $re = '/([\d]{3})([\d]{3})([\d]{4})/';
        $str = $msisdn;
        $subst = '($1) $2-$3';

        $result = preg_replace($re, $subst, $str);
        return $result;
    }

    public function queryData($order_id){
        $query = db_select('vtex_orders', 'vo');
        $query->addField('vo', 'json_address');
        $query->addField('vo', 'client_phone');
        $query->condition('vo.order_id', $order_id, '=');
        $result = $query->execute()->fetchObject();
        $return = (array) json_decode($result->json_address);
        $return['client_phone'] = $result->client_phone;
        return $return;
    }
}
