<?php
/**
 * @file
 * Contains \Drupal\transformation_activation\Form\ActivateSim.
 */
namespace Drupal\transformation_activation\Form;

use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;
use Drupal\transformation_activation\ValidateActivation;
use Drupal\Core\Url;


class ActivateSim extends FormBase
{
  private $arrStatus = array();

  public function getFormId()
  {
    return 'transformation_activation_activate_sim';
  }

  protected function myForm(array $form, FormStateInterface $form_state, $msisdn = null, $token)
  {
    $numberPhone = isset($_COOKIE['Drupal_visitor_msisdn']) ? $_COOKIE['Drupal_visitor_msisdn'] : $msisdn;
    $pattern = '/([0-9]{3})([0-9]{3})([0-9]{4})/i';
    $substitute = '($1) $2-$3';

    $numberPhone = preg_replace($pattern, $substitute, $numberPhone);
    $form['authentication_token'] = [
      '#type' => 'hidden',
      '#value' => $token
    ];

    $form['phone'] = [
      '#type' => 'markup',
      '#markup' => $numberPhone
    ];

    $form['email'] = array(
      '#type' => 'email',
      '#placeholder' => t('Email'),
      '#pattern' => '[a-zA-Z0-9][\w\-\.]{0,}[\w]{1}@[a-zA-Z0-9][\w\-]{1,}\.[a-z]{2,4}(\.[a-z]{2})?',
      '#required' => true,
    );

    $form['email']['#theme_wrappers'] = array();

    $form['label'] = array(
      '#type' => 'label',
      '#title' => t('Email'),
      '#id' => 'edit-email',
    );

    $form['#theme'] = 'transformation-activation-activate-sim';
    $form['#attached']['library'][] = 'transformation_activation/transformation_activation';

    $form['#attributes']['novalidate'] = '';
    $form['#attributes']['autocomplete'] = 'off';
    $form['#action'] = "#";

    $form = ValidateActivation::_hsq($form);

    return $form;
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = \Drupal::config('tigo_vtex_api.settings');
    $tigo_act_settings = $config->get('tigo_act_settings');

    $msisdn = false;
    if ($tigo_act_settings['options']['active_enrichment'] == 1) {
      $msisdn = \Drupal::request()->query->get('msisdn')
        ? \Drupal::request()->query->get('msisdn')
        : false;
      $imsi = \Drupal::request()->query->get('imsi')
        ? \Drupal::request()->query->get('imsi')
        : false;
      user_cookie_save([
        'msisdn' => !empty($msisdn)
          ? $msisdn
          : null,
        'imsi' => !empty($imsi)
          ? $imsi
          : null,
      ]);
      $form['wifi_unavailable'] = [
        '#type' => 'hidden',
        '#value' => true
      ];
    }

    $numberPhone = isset($_COOKIE['Drupal_visitor_msisdn'])
      ? $_COOKIE['Drupal_visitor_msisdn']
      : $msisdn;
    $he = \Drupal::request()->query->get('he')
      ? \Drupal::request()->query->get('he')
      : false;

    if (!$he && $tigo_act_settings['options']['active_enrichment'] != 1) {
      user_cookie_save([
        'send_enrichment' => true
      ]);
      // Params for HE route.
      $options['redirect'] = 'transformation_activation.activate_sim';
      return new RedirectResponse(Url::fromRoute('tigoune_enrichment.enrichment_process', $options)->toString());
    }

    // $validate = ValidateActivation::buildValidate();
    // if ($validate) {
    //   return $validate;
    // }

    if ($numberPhone) {
      $uri = 'private://ActivationValidate.txt';
      $token = rand(9, 60000) . strtotime(date('d F Y', strtotime("+1 week"))) . rand(2, 5000);
      $token = md5(base64_encode(serialize($token))) . '|' . time();
      if (!file_exists($uri)) {
        $file = file_save_data($token, $uri, FILE_EXISTS_REPLACE);
      } else {
        $handle = fopen($uri, 'a');
        fwrite($handle, $token . "\n");
        fclose($handle);
      }
      //Llamo form
      $form = $this->myForm($form, $form_state, $msisdn, $token);
      return $form;
    } else {
      return ValidateActivation::NotPhone();
    }
  }

  public function submitForm(array &$form, FormStateInterface $form_state)
  { }
}
