<?php
/**
 * @file
 * Contains \Drupal\transformation_activation\Form\ActivateSim.
 */
namespace Drupal\transformation_activation\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;


class ActivationLogForm extends FormBase
{

    public function getFormId() {
        return 'transformation_activation_logs';
    }


    public function buildForm(array $form, FormStateInterface $form_state) {
        $default_values = isset($_SESSION['activation_logs_filters'])
            ? $_SESSION['activation_logs_filters']
            : FALSE;

        $form['container_filters'] = array(
            '#type' => 'container',
            '#attributes' => array(
                'class' => 'field-filters',
            ),
        );

        $form['container_filters']['email'] = array(
            '#type' => 'email',
            '#title' => $this->t('Email'),
            '#placeholder' => $this->t('Email'),
            '#pattern' => '[a-zA-Z0-9][\w\-\.]{0,}[\w]{1}@[a-zA-Z0-9][\w\-]{1,}\.[a-z]{2,4}(\.[a-z]{2})?',
            '#default_value' => !empty($default_values['email'])
                ? $default_values['email']
                : FALSE,
            '#title_display' => 'after'
        );

        $form['container_filters']['order_id'] = array(
            '#type' => 'textfield',
            '#title' => $this->t('ID pedido'),
            '#placeholder' => $this->t('ID pedido'),
            '#default_value' => !empty($default_values['order_id'])
                ? $default_values['order_id']
                : FALSE,
            '#title_display' => 'after'
        );

        $form['container_filters']['date_from'] = array(
            '#type' => 'datetime',
            '#title' => $this->t('Desde'),
            '#default_value' => !empty($default_values['date_from'])
                ? $default_values['date_from']
                : '',
            '#title_display' => 'after'
        );
        $form['container_filters']['date_to'] = array(
            '#type' => 'datetime',
            '#title' => $this->t('Hasta'),
            '#default_value' => !empty($default_values['date_to'])
                ? $default_values['date_to']
                : '',
            '#title_display' => 'after'
        );

        $form['container_filters']['submit'] = [
            '#type' => 'submit',
            '#value' => 'Filtrar'
        ];

        $disabled = !isset($_SESSION['order_table'])
            ? TRUE
            : FALSE;

        $form['container_filters']['clear'] = [
            '#type' => 'submit',
            '#value' => 'Limpiar filtros',
            '#attributes' => ['class' => ['button--secondary']],
            '#submit' => [
                '::submitClearFilter'
            ],
            '#disabled' => $disabled
        ];

        $header = [
            'created' => 'Fecha',
            'order_id' => 'Id Orden',
            'mail' => 'Correo',
            'log' => 'Log'
        ];
        $output = $this->creationTable();
        $form['container_table'] = array(
            '#type' => 'container',
            '#attributes' => array(
                'class' => 'table-container',
            ),
            '#prefix' => '<div id="order-table-wrapper">',
            '#suffix' => '</div>'
        );
        $form['container_table']['table'] = [
            '#type' => 'table',
            '#header' => $header,
            '#attributes' => ['class' => ['vtex-order-table']],
            '#rows' => $output,
            '#empty' => t('No data info'),
        ];
        $form['container_table']['pager'] = array(
            '#type' => 'pager'
        );
        return $form;
    }

    public function creationTable()
    {
        $default_values = isset($_SESSION['activation_logs_filters'])
            ? $_SESSION['activation_logs_filters']
            : FALSE;
        $query = db_select('transformation_activation_log', 'tal');
        $query->addField('tal', 'created');
        $query->addField('tal', 'order_id');
        $query->addField('tal', 'mail');
        $query->addField('tal', 'log');
        if ($default_values['date_from']) {
            $query->condition('tal.created', $default_values['date_from'], '>=');
        }
        if ($default_values['date_to']) {
            $query->condition('tal.created', $default_values['date_to'], '<=');
        }
        if ($default_values['email']) {
            $query->condition('tal.mail', $default_values['email'], '=');
        }
        if ($default_values['order_id']) {
            $query->condition('tal.order_id', $default_values['order_id'], '=');
        }
        $query->orderBy('tal.created', 'DESC');
        $pager = $query->extend('Drupal\Core\Database\Query\PagerSelectExtender')->limit(30);
        $results = $pager->execute();
        $output = [];
        foreach ($results as $result) {
            $logs = json_decode($result->log);
            $items = [];
            if($logs){
                foreach ($logs as $log){
                    foreach ($log as $key => $value){
                        switch ($key){
                            case 'step':
                                $name = 'Paso';
                                break;
                            case 'log':
                                $name = 'Mensaje';
                                break;
                            case 'code':
                                $name = 'Codigo';
                                break;
                            case 'productid':
                                $name = 'Id producto';
                                break;
                            default:
                                $name = '';
                                break;
                        }
                        if($key == 'data'){
                            $datos = json_decode($value);
                            $children = [];
                            if(is_array($datos) || is_object($datos)){
                                foreach ($datos as $kdat => $dato){
                                    if(!is_object($dato)){
                                        $children[] = [
                                            '#type' => 'markup',
                                            '#markup' => $kdat . ': ' . $dato
                                        ];
                                    }
                                }
                            }

                            $items[] = [
                                '#markup' => "Datos",
                                'children' => [
                                    '#theme' => 'item_list',
                                    '#list_type' => 'ul',
                                    '#wrapper_attributes' => [
                                        'class' => [
                                            'wrapper',
                                        ],
                                    ],
                                    '#attributes' => [
                                        'class' => [
                                            'programtabs-list-pretitle',
                                        ],
                                    ],
                                    '#items' => $children
                                ]
                            ];
                        }else{
                            $items[] = [
                                '#type' => 'markup',
                                '#markup' => $name . ': ' . $value
                            ];
                        }
                    }
                }
            }
            $output[] = [
                'created' => [
                    'data' => [
                        '#type' => 'markup',
                        '#markup' => $result->created
                    ],
                    'class' => 'order_id_table'
                ],
                'order_id' => [
                    'data' => [
                        '#type' => 'markup',
                        '#markup' => $result->order_id
                    ]
                ],
                'mail' => [
                    'data' => [
                        '#type' => 'markup',
                        '#markup' => $result->mail
                    ],
                    'class' => 'client_table'
                ],
                'log' => [
                    'data' => [
                        '#theme' => 'item_list',
                        '#items' => $items
                    ]
                ]
            ];

        }
        return $output;
    }

    public function submitForm(array &$form, FormStateInterface $form_state) {
        $date_from = $form_state->getValue('date_from');
        $date_to = $form_state->getValue('date_to');
        $email = $form_state->getValue('email');
        $order_id = $form_state->getValue('order_id');
        $option = [
            'date_from' => !empty($date_from) ? $date_from : '',
            'date_to' => !empty($date_to) ? $date_to : '',
            'email' => !empty($email) ? $email : '',
            'order_id' => !empty($order_id) ? $order_id : ''

        ];
        $_SESSION['activation_logs_filters'] = $option;

    }

    public function submitClearFilter(array &$form, FormStateInterface $form_state){
        $_SESSION['activation_logs_filters'] = NUll;
    }

    public function validateForm(array &$form, FormStateInterface $form_state) {

    }
}
