<?php
/**
 * @file
 * Contains \Drupal\transformation_activation\Form\PersonalData.
 */
namespace Drupal\transformation_activation\Form;

use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\HttpFoundation;
use Drupal\Core\Form\FormBase;
use Drupal\transformation_activation\ValidateActivation;
use Drupal\transformation_activation\GeneratePdf;
use Drupal\transformation_activation\GenerateXml;
use Drupal\Core\Render\Markup;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\Component\Serialization\Json;
use Drupal\transformation_activation\Activation;


class Contrato extends FormBase {
    //private $options = array();
    public function getFormId() {
        return 'transformation_activation_contrato';
    }

    protected function myForm(array $form, FormStateInterface $form_state)
    {
        $form['return'] = [
            '#type' => 'link',
            '#title' => 'Regresar',
            '#url' => Url::fromRoute('transformation_activation.precontrato'),
            '#attributes' => [
                'class' => [
                    'link-return'
                ]
            ]
        ];

        $form['step_contract'] = [
            '#type' => 'html_tag',
            '#tag' => 'article',
            '#attributes' => [
                'class' => 'steps-contract-form',
            ]
        ];

        $form['step_contract']['foto'] = [
            '#type' => 'photo'
        ];

        $form['step_contract']['firma'] = [
            '#type' => 'sign'
        ];

        $form['step_contract']['cedula'] = [
            '#type' => 'photo_identification'
        ];

        $form['step_contract']['pagare'] = [
            '#type' => 'container',
            '#attributes' => [
                'class' => 'step-pagare-form',
                'id' => 'step-pagare'
            ]
        ];

        $form['step_contract']['pagare']['markup'] = [
            '#markup' => 'Acepta el pagaré'
        ];

        $form['step_contract']['pagare']['button'] = [
            '#name' => 'pagare_upload',
            '#type' => 'submit',
            '#value' => 'Continuar',
            '#submit' => ['::submitShowPagare'],
            '#ajax' => [
                'callback' => '::showPagare',
                'wrapper' => 'step-pagare'
            ]
        ];
        if($form_state->get('send_pagare') 
            && isset($_SESSION['base64_firma'])
            )
        {
            
            $info = $_SESSION['data_pospago'];
            $form['step_contract']['pagare']['contrato_pagare'] = [
                '#theme' => 'tigo-activation-contrato-pagare',
                '#firma' => $_SESSION['base64_firma'],
                '#imsi' => $info['imsi'],
                '#nombre' => $info['moreData']['name'],
                '#fecha' => format_date(strtotime("now"), 'custom', '\d\í\a d \M\e\s m \A\ñ\o Y'),
                '#precio' => $info['moreData']['precio'],
                '#tipo_documento' => $info['docType'],
                '#numero_documento' => $info['docId']
            ];
            $form['step_contract']['pagare']['check_pagare'] = [
                '#type' => 'checkbox',
                '#title' => 'Acepto el Pagaré',
                '#required' => true,
                '#default_value' => 1,
                '#attributes' => [
                    'class' => ['anexo-check']
                ]
            ];

        } 


        $link_url = Url::fromUri(
            'https://www.tigo.com.co/terminos-y-condiciones?__hstc=58445365.7ef0c1ca4f46c8059aaab07af092e8ca.1536857120038.1536857120038.1536864802309.2&__hssc=58445365.7.1536864802309&__hsfp=2344633723',
            [
                'attributes' => 
                [
                    'target' => '_blank'
                ]
            ]
        );
    

        $link = Link::fromTextAndUrl(t('términos y condiciones'), $link_url)->toString();

        $form['step_contract']['check_submit'] = [
            '#type' => 'container',
            '#attributes' => [
                'class' => 'check-submit',
            ]
        ];

        $form['step_contract']['check_submit']['term'] = array(
            '#type' => 'checkbox',
            '#title' => 'Confirmo que la información brindada corresponde a la realidad y acepto ' . $link . ' del contrato',
        );

        $form['step_contract']['check_submit']['activate'] = [
            '#type' => 'submit',
            '#value' => $this->t('Firmar Contrato'),
            '#attributes' => [
                'class' => [
                    'act-activate',
                    'btn-tigo',
                    'btn-tigo--blue'
                ]
            ],
            '#validate' => ['::validateContrato'],
            '#submit' => ['::submitContrato']
        ];

        $form['#attributes']['novalidate'] = '';
        $form['#attributes']['autocomplete'] = 'off';
        $form['#attached']['library'][] = 'transformation_activation/transformation_activation';
        $form['#attached']['library'][] = 'tigo/tigo.local_session';
        $form = ValidateActivation::_hsq($form);
        return $form;
    }

    public function showPagare(array $form, FormStateInterface $form_state)
    {
        return $form['step_contract']['pagare'];
    }

    public function submitShowPagare(array $form, FormStateInterface $form_state)
    {
        $form_state->set('send_pagare', 1);
        $form_state->setRebuild();
    }

    

    public function buildForm(array $form, FormStateInterface $form_state) {
        if(!isset($_SESSION['data_pospago'])){
            if(isset($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['SERVER_NAME']){
                $base_url = $_SERVER['HTTP_X_FORWARDED_PROTO'] . '://' . $_SERVER['SERVER_NAME'];
            }else{
                global $base_url;
            }
            header('Location: '.$base_url . '/servicios/activate');
            exit;
        }
        $validate = ValidateActivation::buildValidate();
        if($validate){
            return $validate;
        }

        ValidateActivation::validateMail();

        //Llamo form
        $form = $this->myForm($form, $form_state);
        return $form;

    }

    public function submitForm(array &$form, FormStateInterface $form_state) {

    }

    public function submitContrato(array &$form, FormStateInterface $form_state) {
        Activation::SubmitGeneratePdf();
        $form_state->setRedirect('transformation_activation.package_detail');
    }


    public function validateContrato(array &$form, FormStateInterface $form_state) 
    {
        if(!isset($_SESSION['path_photo_selfie'])){
            $form_state->setErrorByName(
                'foto', Markup::create(
                    '<span class="err_contract" data-error="1"><b>Paso 1:</b></span> No se identifico la foto de perfil, Por favor agregala'
                )
            );
        }
        $firma = TRUE;
        if(!isset($_SESSION['path_firma'])){
            $firma = FALSE;
            $form_state->setErrorByName(
                'firma', Markup::create(
                    '<span class="err_contract" data-error="2"><b>Paso 2:</b></span> Tu firma no es válida. Por favor escribe con tu dedo o con un lapicero stylus en el área indicada'
                )
            );
        }
        
        if(!isset($_SESSION['path_identification_front'])){
            $form_state->setErrorByName(
                'cedula', Markup::create(
                    '<span class="err_contract" data-error="3"><b>Paso 3:</b></span> No se identifico la foto de la cédula frontal, Por favor agregala'
                )
            );
        }

        $cedula = TRUE;
        if(!isset($_SESSION['path_identification_back'])){
            $cedula = FALSE;
            $form_state->setErrorByName(
                'cedula', Markup::create(
                    '<span class="err_contract" data-error="3"><b>Paso 3:</b></span> La foto de tu cédula es borrosa y no podemos identificar tus datos. Por favor escanéala de nuevo'
                )
            );
        }

        if($firma || $cedula){
            $logDate = isset($_COOKIE['Drupal_visitor_date'])
                ? $_COOKIE['Drupal_visitor_date']
                : '';
            $logLog = isset($_SESSION['step_log'])
                ? (array) json_decode($_SESSION['step_log'])
                : '';
            $logLog[4] = [
                'step' => 'Firma Contrato',
                'log' => 'Validacion campos ',
                'data' => json_encode([
                    'foto' => 'Correcto',
                    'firma' => $firma
                        ? 'Incorrecta'
                        : 'Correcto',
                    'Cedula' => $cedula
                        ? 'Incorrecta'
                        : 'Correcto'
                ])
            ];
            $info = $_SESSION['data_pospago'];
            $log_enconde = json_encode($logLog);
            Activation::queryLogUpdate($info['moreData']['email'], $logDate, $log_enconde);
        }
        $term = $form_state->getValue('term');
        if(!$term){
            $form_state->setErrorByName('term', 'Debe aceptar los términos y condiciones');
        }
    }

    public function validateForm(array &$form, FormStateInterface $form_state) {

    }
}
