<?php
/**
 * @file
 * Contains \Drupal\transformation_activation\Form\ActivateSim.
 */
namespace Drupal\transformation_activation\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;
use Drupal\transformation_activation\Activation;


class CustomActivation extends FormBase
{

    public function getFormId() {
        return 'tigo_custom_activation';
    }


    public function buildForm(array $form, FormStateInterface $form_state) {

        $order_id = !empty(\Drupal::request()->query->get('order_id'))
            ? \Drupal::request()->query->get('order_id')
            : FALSE;
        $form['order_id'] = [
            '#type' => 'textfield',
            '#title' => $this->t('Id Pedido'),
            '#default_value' => $order_id
        ];
        $query = db_select('vtex_orders', 'vo');
        $query->addField('vo', 'order_id');
        $query->addField('vo', 'product_id');
        $query->addField('vo', 'description');
        $query->condition('vo.order_id', $order_id, '=');
        $query->condition('vo.status', 'invoiced', '=');
        $query->condition('vo.activation_status', Activation::validCodeActivation(), 'NOT IN');
        $query->condition('vo.msisdn', 0, '>');
        $query->condition('vo.imsi', 0, '>');
        $result = $query->execute();
        $item['-none-'] = 'Seleccione un valor';
        $flag = FALSE;
        foreach ($result as $value){
            $flag = TRUE;
            $item[$value->product_id] = $value->description;
        }
        if($flag){
            $form['order_id']['#disabled'] = TRUE;
            $form['product_id'] = [
                '#type' => 'select',
                '#options' =>  $item,
                '#ajax' => [
                    'callback' => '::filterProduct',
                    'wrapper' => 'container-product'
                ]
            ];
            $product_id = $form_state->getValue('product_id');
            if($product_id && is_numeric($product_id)){
                $query1 = db_select('vtex_orders', 'vo');
                $query1->addField('vo', 'msisdn');
                $query1->addField('vo', 'imsi');
                $query1->addField('vo', 'client_document');
                $query1->condition('vo.order_id', $order_id, '=');
                $query1->condition('vo.status', 'invoiced', '=');
                $query1->condition('vo.activation_status', Activation::validCodeActivation(), 'NOT IN');
                $query1->condition('vo.msisdn', 0, '>');
                $query1->condition('vo.imsi', 0, '>');
                $query1->condition('vo.product_id', $product_id, '=');
                $result1 = $query1->execute()->fetchObject();
            }
            $form['container'] = array(
                '#type' => 'container',
                '#attributes' => array(
                    'class' => 'filter-container-status',
                ),
                '#prefix' => '<div id="container-product">',
                '#suffix' => '</div>'
            );
            $form['container']['imsi'] = [
                '#type' => 'textfield',
                '#title' => $this->t('Imsi'),
                '#disabled' => TRUE,
                '#required' => TRUE,
                '#value' => !empty($result1->imsi)
                    ? $result1->imsi
                    : FALSE
            ];
            $form['container']['msisdn'] = [
                '#type' => 'textfield',
                '#title' => $this->t('Msisdn'),
                '#disabled' => TRUE,
                '#required' => TRUE,
                '#value' => !empty($result1->msisdn)
                    ? $result1->msisdn
                    : FALSE
            ];

            $form['container']['id_type'] = array(
                '#type' => 'textfield',
                '#title' => $this->t('Tipo'),
                '#default_value' => 'CC',
                '#disabled' => TRUE
            );

            $form['container']['id_document'] = array(
                '#type' => 'number',
                '#title' => $this->t('Número de documento'),
                '#placeholder' => $this->t('Número de documento'),
                '#value' => !empty($result1->client_document)
                    ? $result1->client_document
                    : FALSE,
                '#required' => TRUE,
                '#disabled' => TRUE
            );
            $currentYear = (int) date('Y');
            $options = array(0=>'Seleccione un año');

            for ($i = $currentYear; $i >= $currentYear-80; $i--) {
                $options[$i]=$i;
            }
            $form['container']['expedition_year'] = array(
                '#type' => 'select',
                '#title' => $this->t('Año expedicion de la cedula'),
                '#options' => $options,
                '#default_value' => 0,
                '#required' => TRUE
            );
        }
        $form['save'] = [
            '#type' => 'submit',
            '#value' => $this->t('Send'),
        ];
        $form['reset'] = [
            '#type' => 'submit',
            '#value' => $this->t('Reset'),
            '#submit' => [
                '::submitReset'
            ]
        ];

        return $form;
    }

    public function filterProduct(array &$form, FormStateInterface $form_state) {
        return $form['container'];
    }

    public function submitReset(array &$form, FormStateInterface $form_state) {
        $url = \Drupal\Core\Url::fromRoute('transformation_activation.form_custom_activation');
        $form_state->setRedirectUrl($url);
    }

    public function submitForm(array &$form, FormStateInterface $form_state) {
        $arg_order_id = !empty(\Drupal::request()->query->get('order_id'))
            ? \Drupal::request()->query->get('order_id')
            : FALSE;
        $order_id = $form_state->getValue('order_id');
        if(!$arg_order_id){
            $url = \Drupal\Core\Url::fromRoute('transformation_activation.form_custom_activation',
                [
                    'order_id' => !empty($order_id)
                        ? $order_id
                        : ''
                ]
            );
        }else{
            $data = [
                'msisdn' => $form_state->getValue('msisdn'),
                'imsi' => $form_state->getValue('imsi'),
                'docType' => $form_state->getValue('id_type'),
                'docId' => $form_state->getValue('id_document'),
                'year' => $form_state->getValue('expedition_year'),
                'productId' => $form_state->getValue('product_id'),
                'transactionId' => 'WSEC' . $order_id . 'P' . $form_state->getValue('product_id')
            ];
            // get service and product ID to activate
            $service = \Drupal::service('tigo_ativation.ativation_process');
            // Call to activation service
            $service->activation($data);
            $response = $service->getResponse();

            Activation::activateSim($response, $data, 1);
            $url = \Drupal\Core\Url::fromRoute('transformation_activation.form_custom_activation');
        }
        $form_state->setRedirectUrl($url);

    }

    public function validateForm(array &$form, FormStateInterface $form_state) {

    }
}
