<?php

namespace Drupal\transformation_activation\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Url;
use Drupal\transformation_activation\ValidateActivation;

/**
 * Show list of products.
 */
class NumbersAvailable extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'transformation_activation_numbers_available';
  }

  /**
   * {@inheritdoc}
   */
  protected function myForm(array $form, FormStateInterface $form_state) {
    \Drupal::service('page_cache_kill_switch')->trigger();
    $tempstore = \Drupal::service('tempstore.private');
    $qvantel = \Drupal::service('transformation.qvantel_services');
    $request_time = \Drupal::time()->getCurrentTime();
    $store = $tempstore->get('transformation_activation');
    $msisdn = isset($_COOKIE['Drupal_visitor_msisdn'])
    ? $_COOKIE['Drupal_visitor_msisdn'] : '';
    // Creation ID reservation based on dummy msisdn and
    // current tiemstamp.
    $reserved_for = 'vv' . $msisdn . $request_time;
    $store->set('reserved_for', $reserved_for);
    $response = $qvantel->reservationMsisdn($reserved_for);
    $options = [];

    if (!array_key_exists('error', $response)) {
      foreach ($response as $value => $key) {
        $prefix = substr($key, 0, 2);
        // Add phone number format.
        $numbers = ValidateActivation::FormatNumber($key, $prefix);
        $options[$key] = '<div class="available-numbers">
          <p>Línea ' . ($value + 1) . '.</p>
          <span>' . $numbers . '</span></div>';
      }
      $form['numbers'] = [
        '#type' => 'radios',
        '#options' => $options,
        '#validated' => TRUE,
        '#required' => TRUE,
      ];
      $form['return'] = [
        '#title' => $this->t(''),
        '#type' => 'link',
        // '#url' => Url::fromRoute('transformation_activation.package_service'),
        '#url' => Url::fromRoute('transformation_activation.personal_data'),
        '#attributes' => [
          'class' => ['button-return'],
        ],
      ];
      $form['actions']['activate'] = [
        '#type' => 'item',
        '#prefix' => '<div class="act-activate btn-ajax disable">',
        '#markup' => '<div class="item-continue">continuar</div>',
        '#suffix' => '</div>',
      ];

      $form['#theme'] = 'transformation-activation-numbers-available';
      $form['#attached']['library'][] = 'transformation_activation/transformation_activation';
      $form = ValidateActivation::_hsq($form);

      return $form;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // $validate = ValidateActivation::buildValidate();

    // if ($validate) {
    //   return $validate;
    // }

    ValidateActivation::validateMail();

    // Call form.
    $form = $this->myForm($form, $form_state);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {}

}
