<?php

namespace Drupal\transformation_activation\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Url;
use Drupal\transformation_activation\ValidateActivation;
use Drupal\transformation_activation\Activation;
/**
 * Show list of products.
 */
class PackageService extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'transformation_activation_package_service';
  }

  /**
   * {@inheritdoc}
   */
  protected function myForm(array $form, FormStateInterface $form_state) {
    // Disable cache for anonymous users.
    \Drupal::service('page_cache_kill_switch')->trigger();
    $tempstore = \Drupal::service('tempstore.private');
    $store = $tempstore->get('transformation_activation');
    $document = (null ==! $store->get('id_document'))
    ? $store->get('id_document') : '';
    $type = (null ==! $store->get('id_type'))
    ? $store->get('id_type') : '';

    $qvantel = \Drupal::service('transformation.qvantel_services');
    // Get account ID.
    $account_id = $qvantel->find('customer-accounts', $document, $type);
    $store->set('account_id_find', $account_id);
    // Get Packages availables.
    $result = $qvantel->packages($account_id);
    $arr1 = [];
    $orders = [];
    $count = [];
    if (!array_key_exists('error', $result)) {
      foreach ($result as $key => $value) {
        $count[$value['product']] = isset($count[$value['product']])
        ? $count[$value['product']] + 1 : 1;
        $orders[] = [
          'basket' => $key,
          'product_id' => $value['product'],
        ];
        $description = $value['description'];
        $arr1[$value['product']] = '<div class="product plan-' . $value['product'] . '" data-value="' . $count[$value['product']] . '">' . $description . '</div><span class="triangle"></span>';
      }
      $form['product'] = [
        '#type' => 'radios',
        '#options' => $arr1,
        '#default_value' => key($arr1),
        '#required' => TRUE,
      ];
      $form['modal']['return'] = [
        '#title' => $this->t(''),
        '#type' => 'link',
        '#url' => Url::fromRoute('transformation_activation.activate_sim'),
        '#attributes' => [
          'class' => ['button-return'],
        ],
      ];
       $form['modal']['use'] = [
        '#type' => 'radios',
        '#options' => [
          'si' => t('Sí'),
          'no' => t('No'),
        ],
        '#default_value' => 'si',
        '#required' => TRUE,
      ];
      $form['modal']['name'] = [
        '#type' => 'textfield',
        '#placeholder' => $this->t('Nombre'),
        '#required' => FALSE,
        '#field_suffix' => 'Nombre',
        '#attributes' => [
          'class' => ['form-control'],
        ],
      ];
      $form['modal']['type'] = [
        '#type' => 'select',
        '#options' => [
          'CC' => 'CC',
          'CE' => 'CE',
        ],
        '#default_value' => 'cc',
        '#required' => FALSE,
      ];
      $form['modal']['id'] = [
        '#type' => 'textfield',
        '#maxlength' => 13,
        '#placeholder' => $this->t('Número de documento'),
        '#required' => FALSE
        ,
        '#attributes' => [
          'data-format-document' => TRUE,
          'data-number' => '0',
          'pattern' => '[\d\.]{1,13}',
          'tabindex' => '2',
          'class' => ['form-document'],
        ],
      ];
      $currentYear = (int)date('Y');
      $options = [0 => 'Año de expedición'];
      for ($i = $currentYear; $i >= $currentYear - 80; $i--) {
        $options[$i] = $i;
        $form['modal']['expedition_year'] = [
          '#type' => 'select',
          '#title' => $this->t('Select element'),
          '#options' => $options,
          '#default_value' => 0,
        ];
      }
      $form['modal']['current_year'] = [
        '#type' => 'markup',
        '#markup' => $currentYear,
      ];
      $form['modal']['email'] = [
        '#type' => 'email',
        '#placeholder' => t('Correo electrónico'),
        '#pattern' => '[a-zA-Z0-9][\w\-\.]{0,}[\w]{1}@[a-zA-Z0-9][\w\-]{1,}\.[a-z]{2,4}(\.[a-z]{2})?',
        '#required' => FALSE,
      ];
      $form['modal']['activate'] = [
        '#type' => 'submit',
        '#value' => $this->t('aceptar'),
        '#attributes' => [
          'class' => ['modal-submit'],
        ],
      ];
      $form['return'] = [
        '#title' => $this->t(''),
        '#type' => 'link',
        '#url' => Url::fromRoute('transformation_activation.activate_sim'),
        '#attributes' => [
          'class' => ['button-return'],
        ],
      ];
      $form['actions']['activate'] = [
        '#type' => 'item',
        '#prefix' => '<div class="act-activate">',
        '#markup' => '<div class="item-continue">continuar</div>',
        '#suffix' => '</div>',
      ];
      $form['baskets'] = [
        '#type' => 'hidden',
        '#value' => json_encode($orders),
      ];
      $form['#theme'] = 'transformation-activation-package-service';
      $form['#attached']['library'][] = 'transformation_activation/transformation_activation';
      // Add new data to the form.
      $form = ValidateActivation::_hsq($form);

      return $form;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // $validate = ValidateActivation::buildValidate();

    // if ($validate) {
    //   return $validate;
    // }

    ValidateActivation::validateMail();

    // Call form.
    $form = $this->myForm($form, $form_state);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $tempstore = \Drupal::service('tempstore.private');
    $store = $tempstore->get('transformation_activation');
    // Product ID selected by user.
    $product_id =  $form_state->getValue('product');
    $store->set('product_id', $product_id);

    // Available orders
    $orders = $form_state->getValue('baskets');

    // If the product_id matches with the selected plan.
    // by default, the first basket in the array is captured.
    foreach (json_decode($orders) as $value) {
      if ($value->product_id == $product_id) {
        $store->set('basket_id', $value->basket);
        break;
      }
    }

    // Storage
    $data = [
      'basket_id' => (NULL ==! $store->get('basket_id'))
        ? $store->get('basket_id') : '',
      'date' => (NULL ==! $store->get('date'))
        ? $store->get('date') : '',
      'client_email' =>(NULL ==! $store->get('client_email'))
        ? $store->get('client_email') : '',
      'product_id' => $product_id,
      'account_id_find' =>(NULL ==! $store->get('account_id_find'))
      ? $store->get('account_id_find') : '',
    ];

    $logLog = [
      'step' => 1,
      'log' => 'plan: ' . $data['product_id']  . ' seleccionado',
      'data' => json_encode($data),
    ];
    $log_enconde = json_encode($logLog);

    // Insert Logs to table transformation_activation_log.
    Activation::queryInsertLog($data['date'], '007', $data['client_email'], $log_enconde);
    \Drupal::logger('orders')->notice(print_r($data, 1));
    $form_state->setRedirect('transformation_activation.personal_data');
  }

}
