<?php

namespace Drupal\transformation_activation\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;
use Drupal\transformation_activation\Activation;
use Drupal\Core\Url;
use Drupal\transformation_activation\ValidateActivation;

/**
 * Show personal data user account.
 */
class PersonalData extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'transformation_activation_personal_data';
  }

  /**
   * {@inheritdoc}
   */
  protected function myForm(array $form, FormStateInterface $form_state) {
    \Drupal::service('page_cache_kill_switch')->trigger();
    $qvantel = \Drupal::service('transformation.qvantel_services');
    $tempstore = \Drupal::service('tempstore.private');
    $store = $tempstore->get('transformation_activation');
    $account_id = (null ==! $store->get('account_id'))
    ? $store->get('account_id') : '';
    $data = $qvantel->getUserDataByAccount($account_id);
    $pattern = '/([0-9]{3})([0-9]{3})([0-9]{4})/i';
    $substitute = '($1) $2-$3';
    $number_phone = isset($_COOKIE['Drupal_visitor_msisdn']) ? $_COOKIE['Drupal_visitor_msisdn'] : '';
    $number_phone = preg_replace($pattern, $substitute, $number_phone);
    $number_document = str_replace(',', '.', number_format($data['id_document']));

    $form['order_id'] = [
      '#type' => 'hidden',
      '#value' => 007,
    ];
    $form['order_real_id'] = [
      '#type' => 'hidden',
      '#value' => 007,
    ];
    $form['phone'] = [
      '#type' => 'markup',
      '#markup' => $number_phone,
    ];
    $form['email'] = [
      '#type' => 'email',
      '#title' => $this->t('Email'),
      '#placeholder' => $this->t('Email'),
      '#default_value' => $data['email'],
      '#disabled' => TRUE,
    ];
    $form['name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Nombre'),
      '#placeholder' => $this->t('Nombre'),
      '#default_value' => $data['name'],
      '#disabled' => TRUE,
    ];
    $form['id_type'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Tipo'),
      '#default_value' => isset($data['id_type'])
      ? $data['id_type'] : 'CC',
      '#disabled' => TRUE,
    ];
    $form['id_document'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Número de documento'),
      '#placeholder' => $this->t('Número de documento'),
      '#default_value' => $number_document,
      '#disabled' => TRUE,
    ];
    $currentYear = (int) date('Y');
    $options = [0 => 'Seleccione un año'];
    for ($i = $currentYear; $i >= $currentYear - 80; $i--) {
      $options[$i] = $i;
      $form['expedition_year'] = [
        '#type' => 'select',
        '#title' => $this->t('Select element'),
        '#options' => $options,
        '#default_value' => 0,
      ];
    }
    $form['current_year'] = [
      '#type' => 'markup',
      '#markup' => $currentYear,
    ];
    $form['data'] = [
      '#type' => 'hidden',
      '#value' => json_encode($data),
    ];
    $form['actions']['return'] = [
      '#title' => $this->t(''),
      '#type' => 'link',
      '#url' => Url:: fromRoute('transformation_activation.package_service'),
      '#attributes' => [
        'class' => ['button-return'],
      ],
    ];
    $form['actions']['continue'] = [
      '#type' => 'submit',
      '#value' => $this->t('continuar'),
      '#attributes' => [
        'disabled' => 'disabled',
        'class' => [
          'act-continue',
          'button--secondary',
        ],
      ],
    ];

    $form['email']['#theme_wrappers'] = [];
    $form['name']['#theme_wrappers'] = [];
    $form['id_document']['#theme_wrappers'] = [];
    $form['expedition_year']['#theme_wrappers'] = [];
    $form['#theme'] = 'transformation-activation-personal-data';
    $form['#attached']['library'][] = 'transformation_activation/transformation_activation';
    $form['#attributes']['novalidate'] = '';
    $form['#attributes']['autocomplete'] = 'off';
    $form = ValidateActivation::_hsq($form);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // $validate = ValidateActivation::buildValidate();

    // if ($validate) {
    //   return $validate;
    // }

    ValidateActivation::validateMail();
    // Call form.
    $form = $this->myForm($form, $form_state);

    return $form;

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $tempstore = \Drupal::service('tempstore.private');
    $store = $tempstore->get('transformation_activation');
    $data = $form_state->getValue('data');
    $data = json_decode($data, TRUE);
    $config = \Drupal::config('tigo_vtex_api.settings')->get('transformation_act');
    $cList = isset($config['black_list']) ? $config['black_list'] : TRUE;
    $cDate = isset($config['expedition_date']) ? $config['expedition_date'] : TRUE;
    $black_list = TRUE;
    $expedition_date = TRUE;
    $qvantel = \Drupal::service('transformation.qvantel_services');

    if ($cList || $cDate) {
      $number_document = $form_state->getValue('id_document');
      $document = str_replace('.', '', $number_document);
      $type = $form_state->getValue('id_type');
    }
    if ($cList) {
      $black_list = $qvantel->validateOnBlackList($type, $document);
    }
    if ($cDate) {
      $expedition = $form_state->getValue('expedition_year');
      $typeId = ValidateActivation::GetTypeDocument($type);

      $data_credit = $qvantel->getDataCredit($config['datacredit'], $document, $typeId);
      $expedition_date = isset($data_credit) && $data_credit == $expedition ? TRUE : FALSE;
    }
    if ($black_list) {
      if ($expedition_date) {

        // Storage.
        $data['date'] = (NULL ==! $store->get('date'))
        ? $store->get('date') : '';
        $data[ 'client_email'] = (NULL ==! $store->get('client_email'))
        ? $store->get('client_email') : '';
        // Reemplazar mas adelante por tempstore.
        $data['msisdn'] = isset($_COOKIE['Drupal_visitor_msisdn'])
        ? $_COOKIE['Drupal_visitor_msisdn'] : '';

        $logLog = [
          'step' => 2,
          'log' => 'Usuario ingresa fecha expedicion correctamente',
          'data' => json_encode($data),
        ];
        $log_enconde = json_encode($logLog);
        Activation:: queryLogUpdate($data['client_email'], $data['date'], $log_enconde);
        \Drupal::logger('orders')->notice(print_r($data, 1));
        $form_state->setRedirect('transformation_activation.numbers_available');
      }
      else {
        $var = $_SESSION['error_expedition'] += 1;
        $try = isset($config['datacredit']['try']) ? $config['datacredit']['try'] : 3;
        if ($var >= $try) {
          $form_state->setRedirect('transformation_activation.error');
        }
        else {
          drupal_set_message($config['bl_message'] . ' Error fecha de expedicion', 'error');
        }
      }
    }
    else {
      drupal_set_message($config['bl_message'] . ' Error listas negras', 'error');
    }
  }

}
