<?php

namespace Drupal\transformation_activation\Form;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\HtmlCommand;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\transformation_activation\Manager\StepManager;
use Drupal\transformation_activation\Step\StepsEnum;
use Drupal\Core\Ajax\RedirectCommand;
use Drupal\transformation_activation\Activation;
use Drupal\Core\Url;
use Drupal\Core\Ajax\InvokeCommand;

/**
 * Provides multi step ajax example form.
 *
 * @package Drupal\transformation_activation\Form
 */
class Preguntas extends FormBase {
  use StringTranslationTrait;

  /**
   * Step Id.
   *
   * @var \Drupal\transformation_activation\Step\StepsEnum
   */
  protected $stepId;

  /**
   * Multi steps of the form.
   *
   * @var \Drupal\transformation_activation\Step\StepInterface
   */
  protected $step;

  /**
   * Step manager instance.
   *
   * @var \Drupal\transformation_activation\Manager\StepManager
   */
  protected $stepManager;

  /**
   * {@inheritdoc}
   */
  public function __construct() {
    $this->stepId = StepsEnum::STEP_ONE;
    $this->stepManager = new StepManager();
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'transformation_activation_question_multi_step';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    if(!isset($_SESSION['security_question'])
    || empty($_SESSION['security_question']) 
    || count($_SESSION['security_question']) < 3){
        if(isset($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['SERVER_NAME']){
          $base_url = $_SERVER['HTTP_X_FORWARDED_PROTO'] . '://' . $_SERVER['SERVER_NAME'];
        }else{
          global $base_url;
        }
        header('Location: '.$base_url . '/servicios/activate');
        exit;
    }
    $form['#attached']['library'][] = 'transformation_activation/transformation_activation';
    $form['#prefix'] = '<section class="questions-content">';
    $form['#suffix'] = '</section>';
    $form['label'] = [
      '#type' => 'markup',
      '#prefix' => '<div class="content-top-description content-shadow"><div class="blocked-icon"></div><div class="title-description"><h2>Preguntas de seguridad</h2>',
      '#markup' => '<div class="description-page">No hemos podido validar los datos de tu documento, ayúdanos respondiendo las siguientes preguntas:</div></div>',
      '#suffix' => '</div>'
    ];
    $form['wrapper-messages'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'messages-wrapper',
      ],
    ];

    $form['wrapper'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'form-wrapper',
        'class' => 'content-shadow form-questions'
      ],
    ];

    // Get step from step manager.
    $this->step = $this->stepManager->getStep($this->stepId);

    // Attach step form elements.
    $form['wrapper'] += $this->step->buildStepFormElements();

    // Attach buttons.
    $form['wrapper']['actions']['#type'] = 'actions';
    $buttons = $this->step->getButtons();
    foreach ($buttons as $button) {
      /** @var \Drupal\transformation_activation\Button\ButtonInterface $button */
      $form['wrapper']['actions'][$button->getKey()] = $button->build();

      if ($button->ajaxify()) {
        // Add ajax to button.
        $form['wrapper']['actions'][$button->getKey()]['#ajax'] = [
          'callback' => [$this, 'loadStep'],
          'wrapper' => 'form-wrapper',
          'effect' => 'fade',
        ];
      }

      $callable = [$this, $button->getSubmitHandler()];
      if ($button->getSubmitHandler() && is_callable($callable)) {
        // Attach submit handler to button, so we can execute it later on..
        $form['wrapper']['actions'][$button->getKey()]['#submit_handler'] = $button->getSubmitHandler();
      }
    }

    return $form;

  }

  /**
   * Ajax callback to load new step.
   *
   * @param array $form
   *   Form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Form state interface.
   *
   * @return \Drupal\Core\Ajax\AjaxResponse
   *   Ajax response.
   */
  public function loadStep(array &$form, FormStateInterface $form_state) {
    $response = new AjaxResponse();
    if($form_state->getValue('question_2') && $form_state->get('send')){
      Activation::SubmitGeneratePdf();
      sleep(2);
      $alias = \Drupal::service('path.alias_manager')->getAliasByPath('/servicios/activate/paso3');
      $redirect = new RedirectCommand($alias);
      $response->addCommand($redirect);
      return $response;
    } elseif ($form_state->getValue('question_2')) {
        $response->addCommand(new InvokeCommand(NULL, 'stepTryAgain', [true]));
    }

      $messages = drupal_get_messages();
      if (!empty($messages)) {
        // Form did not validate, get messages and render them.
        $messages = [
          '#theme' => 'status_messages',
          '#message_list' => $messages,
          '#status_headings' => [
            'status' => $this->t('Status message'),
            'error' => $this->t('Error message'),
            'warning' => $this->t('Warning message'),
          ],
        ];
        $response->addCommand(new HtmlCommand('#messages-wrapper', $messages));
      }
      else {
        // Remove messages.
        $response->addCommand(new HtmlCommand('#messages-wrapper', ''));
      }

      // Update Form.
      $response->addCommand(new HtmlCommand('#form-wrapper',
        $form['wrapper']));
    

    return $response;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $triggering_element = $form_state->getTriggeringElement();
    // Only validate if validation doesn't have to be skipped.
    // For example on "previous" button.
    if (empty($triggering_element['#skip_validation']) && $fields_validators = $this->step->getFieldsValidators()) {
      // Validate fields.
      foreach ($fields_validators as $field => $validators) {
        // Validate all validators for field.
        $field_value = $form_state->getValue($field);
        foreach ($validators as $validator) {
          if (!$validator->validates($field_value)) {
            $form_state->setErrorByName($field, $validator->getErrorMessage());
          }
        }
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Save filled values to step. So we can use them as default_value later on.
    $values = [];
    foreach ($this->step->getFieldNames() as $name) {
      $values[$name] = $form_state->getValue($name);
    }
    $this->step->setValues($values);
    // Add step to manager.
    $this->stepManager->addStep($this->step);
    // Set step to navigate to.
    $triggering_element = $form_state->getTriggeringElement();
    $this->stepId = $triggering_element['#goto_step'];

    // If an extra submit handler is set, execute it.
    // We already tested if it is callable before.
    if (isset($triggering_element['#submit_handler'])) {
      $this->{$triggering_element['#submit_handler']}($form, $form_state);
    }
    
    $form_state->setRebuild(TRUE);
  }

  /**
   * Submit handler for last step of form.
   *
   * @param array $form
   *   Form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Form state interface.
   */
  public function submitValues(array &$form, FormStateInterface $form_state) {
    $flag = true;
    foreach ($this->stepManager->getAllSteps() as $key => $value) {
      $tkey = $key - 1;
      $answer = $_SESSION['security_answer_' . $tkey];
      $question = array_values($value->getValues());
      if($answer != $question[0]){
        $flag = false;
        break;
      }
    }
    $form_state->set('send', $flag);
  }
}
