<?php

namespace Drupal\transformation_activation\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Markup;

/**
 * Defines a form that configures forms module settings.
 */
class SecurityQuestionAdd extends FormBase
{

	/**
	 * {@inheritdoc}
	 */
	public function getFormId() {
		return 'transformation_activation_security_question_add';
	}



	/**
	 * {@inheritdoc}
	 */
	public function buildForm(array $form, FormStateInterface $form_state, $id = NULL) {
		$form['#attached']['library'][] = 'transformation_activation/transformation_activation.questions';
		$result = FALSE;
		if(isset($id) && is_numeric($id)){
			$form['edit'] = [
				'#type' => 'hidden',
				'#value' => $id
			];
			$query = db_select('transformation_activation_security_questions', 'sc');
			$query->addField('sc', 'question');
			$query->addField('sc', 'answer');
			$query->addField('sc', 'number');
			$query->addField('sc', 'path');
			$query->condition('sc.id', $id, '=');
			$result = $query->execute()->fetchObject();

		}
		$form['question'] = [
			'#type' => 'textfield',
			'#title' => 'Pregunta',
			'#required' => TRUE,
			'#default_value' => isset($result->question)
				? $result->question
				: FALSE
		];

		$form['number'] = [
            '#type' => 'checkbox',
			'#title' => 'Si marca esta opción una respuesta vuelve random los numeros que tiene la respuesta',
			'#default_value' => isset($result->number)
				? $result->number
				: FALSE
		];

		$service = \Drupal::service('tigo_vtex_api.vtex_call');
		$json = $service->vtexOrderId("859170782855-01");

		$form['json'] = [
			'#type' => 'hidden',
			'#value' => $json,
			'#attributes' => [
                'id' => [
                    'json-data'
                ]
            ],
		];
		
		$form['path'] = [
			'#type' => 'textfield',
			'#title' => 'Ruta respuesta',
			'#required' => TRUE,
			'#default_value' => isset($result->path)
				? $result->path
				: FALSE
		];

		$form['answer'] = [
			'#type' => 'textarea',
			'#title' => 'Respuestas',
			'#required' => TRUE,
			'#default_value' => isset($result->answer)
				? $result->answer
				: FALSE
		];

		$form['submit'] = [
			'#type' => 'submit',
			'#value' => 'Guardar',
		];
		return $form;
	}

	/**
	 * {@inheritdoc}
	 */
	public function validateForm(array &$form, FormStateInterface $form_state) {
		$json = $form_state->getValue('json');
		$new_json = (array) json_decode($json);

		$explode = explode('->', $form_state->getValue('path'));
		foreach($explode as $value){
			if(isset($new_json[$value])){
				$new_json =  (array) $new_json[$value];
			}			
		}
		if(empty($new_json[0])){
			$form_state->setErrorByName('path', 'No se detecto información en esa ruta');
		}
	}

	/**
	 * {@inheritdoc}
	 */
	public function submitForm(array &$form, FormStateInterface $form_state) {
		$edit = $form_state->getValue('edit');
		$values = [
			'question' => $form_state->getValue('question'),
			'answer' => $form_state->getValue('answer'),
			'number' => (int) $form_state->getValue('number'),
			'path' => $form_state->getValue('path')
		];
		$connection = \Drupal::database();
		if(isset($edit)){
			$connection->update('transformation_activation_security_questions')
				->fields($values)
				->condition('id', $edit)
				->execute();
		}else{
			$connection->insert('transformation_activation_security_questions')
				->fields(
					[
						'question',
						'answer',
						'number',
						'path'
					])
				->values($values)
				->execute();
		}
		$form_state->setRedirect('transformation_activation_admin.security_questions');
	}
}
