<?php
namespace Drupal\transformation_activation;

use Drupal\tigo_vtex_manage_orders\BatchInserOrder;

/**
 * Class Orders
 * @package Drupal\transformation_activation
 */
class Orders {

  // Order data.
  private $dealer_id;
  private $order_id;
  private $client_name;
  private $client_document;
  private $client_phone;
  private $client_email;
  private $description;
  private $dealer_info;
  private $creation_date;
  private $total_value;
  private $selling_price;
  private $json_address;
  private $ref_id;
  private $quantity;
  private $payment_name;
  private $sequence;

  // Required fields to db insert.
  static $required_fields;

  /**
   * Orders constructor.
   * @param $data
   */
  public function __construct($data, array $required_fields) {
    $this->defineData($data);
    self::$required_fields = $required_fields;
  }

  /**
   * @param $data
   */
  private function defineData($order) {
    foreach($order['included'] as $val_order) {

      if ($val_order['type'] == 'orders') {
        $seller_info = [
          'chain-id' => $val_order['attributes']['sales-info']['chain-id'],
          'salesperson-id' => $val_order['attributes']['sales-info']['salesperson-id'],
          'channel' => $val_order['attributes']['sales-info']['channel'],
          'sales-type' => $val_order['attributes']['sales-info']['sales-type'],
        ];
        $this->dealer_info = json_encode($seller_info);
        $this->order_id = $val_order['id'];
        $this->dealer_id = $val_order['attributes']['sales-info']['dealer-id'];

        $this->creation_date = $val_order['attributes']['created-at'];

      }

      if($val_order['type'] == 'order-prices') {
        $this->total_value = isset($val_order['attributes']['price']['tax-amount'])
          ? $val_order['attributes']['price']['tax-amount'] : '';
        $this->selling_price = $this->total_value;
      }

      if($val_order['type'] == 'order-products') {
        $this->description = isset($val_order['attributes']['inputted-characteristics']['description'])
          ? $val_order['attributes']['inputted-characteristics']['description'] : '';
      }

      if($val_order['type'] == 'order-items') {
        $this->ref_id = isset($val_order['attributes']['target-agreement-id'])
          ? $val_order['attributes']['target-agreement-id'] : '';

        $this->quantity = isset($val_order['attributes']['quantity'])
          ? $val_order['attributes']['quantity'] : '';
      }

      if($val_order['type'] == 'order-payments') {
        $this->payment_name = isset($val_order['attributes']['payment-method']['generic-payment-method']['payment-type'])
          ? $val_order['attributes']['payment-method']['generic-payment-method']['payment-type'] : '';
      }
    }

    $this->client_document = isset($order['user-data']['client-document']) ? $order['user-data']['client-document'] : '';
    $this->client_name = isset($order['user-data']['client-name']) ? $order['user-data']['client-name'] : '';
    $this->client_phone = isset($order['user-data']['client-phone']) ? $order['user-data']['client-phone'] : '';
    $this->client_email = isset($order['user-data']['client-email']) ? $order['user-data']['client-email'] : '';
    $this->sequence = isset($order['user-data']['sequence']) ? $order['user-data']['sequence'] : '';

    if(isset($order['user-data']['json-address'])) {
      $json_address_fields = [
        'addressType',
        'receiverName',
        'addressId',
        'postalCode',
        'city',
        'state',
        'country',
        'street',
        'number',
        'neighborhood',
        'complement',
        'reference',
        'geoCoordinates',
      ];

      $json_address = [];
      foreach($order['user-data']['json-address'] as $key => $value) {
        if(in_array($key, $json_address_fields)) {
          $json_address[$key] = $value;
        }
      }

      $this->json_address = json_encode($json_address);
    }
  }

  /**
   * @param array $requiredFields
   * @return array
   */
  public function verifyRequiredFields() {
    $fields = [];

    foreach(self::$required_fields as $field) {
      if(empty($this->$field)) {
        if($field == 'payment_name') {
          $field = 'payment-type';
        }
        $fields[] = $field;
      }
    }

    return $fields;
  }

  public function validateFields() {
    $pattern = "/(\d)+\-(\d)+\-(\d)+\T(\d)+\:(\d)+\:(\d)+\.(\d)+\+(\d)+\:(\d)+/";
    if(preg_match($pattern, $this->creation_date)) {
      $date = explode('T', $this->creation_date);
      $date = explode('-', $date[0]);
      if(checkdate($date[1], $date[2], $date[0]) == FALSE) {
        return [
          'message' => t('Fecha incorrecta'),
          'code' => 500,
        ];
      }
      else {
        $act_date = \Drupal::time()->getCurrentTime();
        $act_date_str = explode('-', date('Y-m-d', $act_date));

        if(strtotime($date[0].'-'.$date[1].'-'.$date[2]) > $act_date
          || $act_date_str[0] != $date[0]) {
          return [
            'message' => t('Fecha incorrecta'),
            'code' => 500,
          ];
        }
        else {
          $config = \Drupal::config('tigo_vtex_api.settings')->get('seller_tab');
          $date_conf = $config['days_config'];

          if ($date_conf == 0) {
            if($act_date_str[0] != $date[0] || $act_date_str[1] != $date[1] || $act_date_str[2] != $date[2]) {
              return [
                'message' => t('Fecha incorrecta'),
                'code' => 500,
              ];
            }
          }
          else {
            if ($act_date_str[2] - $date_conf <= 0) {
              if ($act_date_str[1] - 1 == 0) {
                $act_date_str[0] = $act_date_str - 1;
              }
              $act_date_str[1] = ($act_date_str[1] - 1 == 0) ? 12 : $act_date_str[1] - 1;
              $days_of_month = cal_days_in_month(CAL_GREGORIAN, $act_date_str[1], $act_date_str[0]);
              $act_date_str[2] = ($act_date_str[2] + $days_of_month) - $date_conf;
            }

            $validate_time = strtotime($act_date_str[0] . '-' . $act_date_str[1] . '-' . $act_date_str[2]);
            if (strtotime($date[0] . '-' . $date[1] . '-' . $date[2]) < $validate_time) {
              return [
                'message' => t('Fecha incorrecta'),
                'code' => 500,
              ];
            }
          }
          list($part1, $part2) = explode('.', $this->creation_date);
          $beginDate = str_replace('T', ' ', $part1);
          $this->creation_date = BatchInserOrder::date_time_zone($beginDate, $part2);
        }
      }
    }
    else {
      return [
        'message' => t('Formato de fecha incorrecto'),
        'code' => 500,
      ];
    }

    return "";
  }

  /**
   * @param Orders $order
   */
  public function pushOrder() {
    try {
      $database = \Drupal::database()->insert('vtex_orders');
      $data = get_object_vars($this);
      $fields = array_keys($data);
      $values = array_values($data);
      $fields[] = 'status';
      $values[] = 'ready-for-handling';
      $database->fields($fields)
        ->values($values)
        ->execute();
      $response = [
        'code' => 200,
        'message' => t('Order created.'),
        'order_id' => $this->order_id,
      ];
    }
    catch(\Exception $e) {
      $message = $e->getCode() == 23000
        ? t('order_id already exists.')
        : t('Error during insertion.');
      $response = [
        'code' => 500,
        'message' => $message,
      ];
    }

    return $response;
  }

  /**
   * @param $field
   * @return mixed
   */
  public function get($field) {
    return $this->$field;
  }

}