<?php

namespace Drupal\transformation_activation\Plugin\rest\resource;

use Drupal\rest\Plugin\ResourceBase;
use Drupal\rest\ModifiedResourceResponse;

/**
 * @RestResource(
 *   id = "delete_order",
 *   label = @Translation("Delete order"),
 *   uri_paths = {
 *     "https://www.drupal.org/link-relations/create" = "/api/seller/remove"
 *   }
 * )
 */
class DeleteRegisterRestResource extends ResourceBase {

  /**
   * @param $data
   * @return ModifiedResourceResponse
   */
  public function post($data) {
    \Drupal::service('page_cache_kill_switch')->trigger();

    // Validate access token.
    $authorization = \Drupal::request()->headers->get('Authorization');
    $token = trim(str_replace('Bearer', '', $authorization));
    if(empty($token)) {
      $response = [
        'code' => 401,
        'status' => $this->t('Authorization required.'),
      ];
      return new ModifiedResourceResponse($response, 401);
    }

    $service = \Drupal::service('tigo_seller_auth.access_token_api');

    if($service->validateSellerAccessToken($token)) {

      // Validate if json data has an order_id field.
      if(!isset($data['order_id'])) {
        $response = [
          'code' => 500,
          'status' => $this->t('the field order_id is required'),
        ];
        return new ModifiedResourceResponse($response, $response['code']);
      }

      $response = [
        'code' => 200,
        'status' => $this->t('Orden eliminada exitosamente.'),
      ];

      try {
        // Validate if order_id register exists.
        $query = \Drupal::database()->select('vtex_orders', 'vo');
        $query->fields('vo', ['order_id']);
        $query->condition('order_id', $data['order_id']);
        $validate = $query->execute()->fetchField();

        if($validate) {
          // Delete register.
          try {
            \Drupal::database()->delete('vtex_orders')
              ->condition('order_id', $data['order_id'])
              ->execute();
          }
          catch (\Exception $e) {
            $response['status'] = $e->getMessage();
            $response['code'] = 400;
            //$response['sqlerror'] = $e->getCode();
          }
        }
        else {
          $response['code'] = 200;
          $response['status'] = $this->t('The order not exists.');
        }

      }
      catch(\Exception $e) {
        $response['code'] = 500;
        $response['status'] = $this->t('Internal server error');
      }

    }
    else {
      $response['code'] = 401;
      $response['status'] = $this->t('Invalid access token.');
    }

    return new ModifiedResourceResponse($response, $response['code']);
  }

}