<?php
namespace Drupal\transformation_activation\Services;

use Drupal\tigoapi\TigoApi;
use Drupal\Core\Render\Markup;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\Core\Datetime\DrupalDateTime;

class QvantelActivationService {

  // Tigo Api var.
  protected $api;
  private $config;
  protected $tempstore;

  /**
   * {@inheritdoc}
   */
  public function __construct(TigoApi $api) {
    $this->api = $api;
    $this->config = \Drupal::config('tigo_vtex_api.settings');
    $this->tempstore = \Drupal::service('tempstore.private');
  }

  /**
   * @param $cer channel external reference -> email
   */
  public function validateCer($cer, $type) {

    $params['tokens'] = [
      'to_search' => $cer,
      'type' => $type,
    ];

    try {
      $account_id = $this->api->consumption('getAccountByCer', $params);
      if(!empty($account_id->data)) {
        $account_id = $account_id->data[0]->id;
      }
      else {
        $account_id = false;
      }
    }
    catch(\Exception $e) {
      $account_id['error'] = $e->getMessage();
      $account_id['code'] = $e->getCode();
    }
    \Drupal::logger('find by CER')->notice(print_r($account_id, 1));
    return $account_id;
  }

  /**
   *
   */
  public function getUserDataByAccount($account_id) {
    try {
      $params['tokens'] = [
        'account_id' => $account_id,
        'info' => ''
      ];
      $user_request = $this->api->consumption('getIndividualInfo', $params);
      $name = (Array) $user_request->data->attributes;

      $params['tokens']['info'] = '/identifications';
      $user_request = $this->api->consumption('getIndividualInfo', $params);
      $data = (Array) $user_request->data[0]->attributes;

      $params['tokens']['info'] = '/contact-media';
      $user_request = $this->api->consumption('getIndividualInfo', $params);
      $email = $user_request->data[0]->attributes->medium->email;

      $response = [
        'name' => $name['given-name'] . ' ' . $name['family-name'],
        'id_type' => $data['identification-type'],
        'id_document' => $data['identification-id'],
        'email' => $email
      ];
    }
    catch(\Exception $e) {
      $response['error'] = $e->getMessage();
      $response['code'] = $e->getCode();
    }

    return $response;
  }

  /**
   *
   */
  public function getDataCredit($data, $document, $type) {
    $params['tokens'] = [
        'idType'    => $data['id_type'],
        'idNumber'  => $data['id_document'],
        'nit'       => $data['nit'],
        'id'        => $document,
        'type'      => $type,
    ];
    try {
      $params['headers']['Content-Type'] = 'application/vnd.api+json';
      $request = $this->api->consumption('getDataCredit', $params);
      $expedition = $request->reporte->informacionBasica->fechaExpedicion;
      if(isset($expedition)) {
        $response = date("Y", strtotime(str_replace('/', '-', $expedition)));
      }
      else {
        $response = false;
      }
    }
    catch(\Exception $e) {
      $response['error'] = $e->getMessage();
      $response['code'] = $e->getCode();
    }
    \Drupal::logger('find by CER')->notice(print_r($response, 1));

    return $response;
  }

  /**
   *
   */
  public function validateOnBlackList($id_type, $id_document) {

    try {
      $body = [
        "data" => [
          "attributes" => [
            "recipe-id" => "customer-blacklisting-validation",
            "parameters" => [
              "identification-id" => $id_document,
              "identification-type" => $id_type
            ]
          ],
          "type" => "eligibility-decisions"
        ]
      ];
      $params['body'] = json_encode($body);
      $params['headers']['Content-Type'] = 'application/vnd.api+json';
      $request = $this->api->consumption('validateOnBlackList', $params);
      \Drupal::logger('response blacklist')->notice(print_r($request, 1));
      $field = 'decision-content';
      $request = $request->data->attributes->$field;
      \Drupal::logger('object blacklist')->notice(print_r($request, 1));

      if($request->status == 'accepted') {
        $response = true;
      }
      else {
        $response = false;
      }
    }
    catch(\Exception $e) {
      $response = true;
    }
    return $response;
  }

  /**
   *
   */
  public function find($type, $document, $doc_type) {

    try {
      $params['tokens'] = [
        'id_document' => $document,
        'id_type' => $doc_type,
      ];
      $request = $this->api->consumption('getIndividualInformation', $params);

      $pointer = $type == 'individuals' ? 'data' : 'included';
      foreach($request->$pointer as $value) {
        if($value->type == $type) {
          return $value->id;
        }
        else {
          $response = false;
        }
      }

    }
    catch(\Exception $e) {
      $response['code'] = $e->getCode();
      $response['error'] = $e->getMessage();
    }

    return $response;
  }

  /**
   *
   */
  public function getOrders($type, $document, $doc_type, $account_id = null) {
    $store = $this->tempstore->get('transformation_activation');
    $response = FALSE;

    try {
      if($account_id == null) {
        $account_id = $this->find('customer-accounts', $document, $doc_type);
      }
      if(!empty($account_id) && !is_array($account_id)) {
        $params['tokens']['account_id'] = $account_id;
        $request = $this->api->consumption('getOrdersByAccountId', $params);
        if($type == 'count') {
          $response = count($request->data);
        }
        else if($type == 'reference') {
          $field = 'reference-number';
          foreach($request->data as $item => $value) {
            if($value->id == $document) {
              $reference_number = isset($value->attributes->$field) ? $value->attributes->$field : FALSE;
              $store->set('reference_number', $reference_number);
              \Drupal::logger('reference number')->notice(print_r($reference_number, 1));
              if ($reference_number !== FALSE) {
                $product_id = $this->getProductId($reference_number);
                $response = $product_id;
              }
            }
          }
        }
        else if($type == 'exist_account') {
          if (isset($request->included)) {
            $response = TRUE;
          }
        }
        else if($type == 'all') {
          $response = $request;
        }
        else {
          $response = $request->data;
        }
      }
      else {
        throw new \Exception('Error al obtener account ID', 500);
      }
    }
    catch(\Exception $e) {
      $response['error'] = $e->getMessage();
      $response['code'] = $e->getCode();
    }

    return $response;
  }

   /**
   *
   */
  public function getProductId($reference_number) {
    $response = FALSE;

    try {
      $params['tokens'] = [
        'reference_number' => $reference_number,
      ];
      $request = $this->api->consumption('getProductId', $params);
      $request_included = isset($request->included) ? $request->included : FALSE;
      \Drupal::logger('include getProductId')->notice(print_r($request_included, 1));

      if ($request_included !== FALSE) {
        foreach($request_included as $item) {
          if($item->type == 'basket-products') {
            $response = isset($item->id) ? $item->id : FALSE;
          }
        }
        \Drupal::logger('response getProductId')->notice(print_r($response, 1));
      }
    }
    catch(\Exception $e) {
      $response['code'] = $e->getCode();
      $response['error'] = $e->getMessage();
    }

    return $response;
  }

  /**
   *
   */
  public function packages($account_id) {

    try {
      $request = $this->getOrders('all', null, null, $account_id);
      $field = 'product-offering';
      $field_alt = 'basket-item';

      foreach($request->included as $value) {
        if($value->type == 'basket-products') {
          // objeto product-offering.
          $offering = $value->relationships->$field;
          // objeto basket-item.
          $item = $value->relationships->$field_alt;
          // 8d1ece10-ee68-414f-84e6-d0156be12edd => PO_Plan_1_x_1.
          $basket_products[$item->data->id] = $offering->data->id;
        }
      }

      $field = 'basket-items';
      foreach($request->data as $value) {
        // Objeto basket-items.
        $b_items = $value->relationships->$field;
        foreach($b_items->data as $b_data) {
          $items[$value->id]['items'][$b_data->id] = $basket_products[$b_data->id];
          $product = $basket_products[$b_data->id];

          $graphql = '{"query":"query {\\n  productOfferings(filter: \\"(EQ id \\\\\\"'.$product.'\\\\\\")\\") {\\n    edges {\\n      node {\\n        id\\n        name\\n\\t\\t\\t\\tcommercialEnrichments {\\n\\t\\t\\t\\t\\tedges {\\n\\t\\t\\t\\t\\t\\tnode {\\n\\t\\t\\t\\t\\t\\t\\tdescriptions {\\n\\t\\t\\t\\t\\t\\t\\t\\tentries {\\n\\t\\t\\t\\t\\t\\t\\t\\t\\tkey\\n\\t\\t\\t\\t\\t\\t\\t\\t\\tvalue\\n\\t\\t\\t\\t\\t\\t\\t\\t}\\n\\t\\t\\t\\t\\t\\t\\t}\\n\\t\\t\\t\\t\\t\\t}\\n\\t\\t\\t\\t\\t}\\n\\t\\t\\t\\t}\\n\\t\\t\\t\\tprices {\\n\\t\\t\\t\\t\\tedges {\\n\\t\\t\\t\\t\\t\\tnode {\\n\\t\\t\\t\\t\\t\\t\\tprice {\\n\\t\\t\\t\\t\\t\\t\\t\\ttaxAmount\\n\\t\\t\\t\\t\\t\\t\\t\\ttaxIncludedAmount\\n\\t\\t\\t\\t\\t\\t\\t\\ttaxRate\\n\\t\\t\\t\\t\\t\\t\\t\\ttaxFreeAmount\\n\\t\\t\\t\\t\\t\\t\\t}\\n\\t\\t\\t\\t\\t\\t}\\n\\t\\t\\t\\t\\t}\\n\\t\\t\\t\\t}\\n\\t\\t\\t\\tallowances {\\n\\t\\t\\t\\t\\tedges {\\n\\t\\t\\t\\t\\t\\tnode {\\n\\t\\t\\t\\t\\t\\t\\tid\\n\\t\\t\\t\\t\\t\\t\\tunitOfMeasure\\n\\t\\t\\t\\t\\t\\t\\tsize\\n\\t\\t\\t\\t\\t\\t\\tgroup\\n\\t\\t\\t\\t\\t\\t}\\n\\t\\t\\t\\t\\t}\\n\\t\\t\\t\\t}\\n      }\\n    }\\n  }\\n}\\n\\n"}';
          $params['body'] = $graphql;
          $packageInfo = $this->api->consumption('getPackageInfo', $params);
          $description = $packageInfo->data->productOfferings->edges[0]->node->commercialEnrichments->edges[0];
          $description = $description->node->descriptions->entries;
          $planDescription = "";

          foreach($description as $dValue) {
            if ($dValue->key == 'short-description' && !empty($dValue->value)) {
              $planDescription = $dValue->value;
            }
          }
          if (!empty($product) && strpos($product, 'PO_Plan') !== TRUE) {
            $items[$value->id]['product'] = $product;
            $items[$value->id]['description'] = $planDescription;
          }
        }
      }
    }
    catch(\Exception $e) {
      $items['error'] = $e->getMessage();
      $items['code'] = $e->getCode();
    }

    return $items;
  }

  /**
   *
   */
  public function getStock($msisdn) {
    $params['tokens']['msisdn'] = $msisdn;
    try {
      $request = $this->api->consumption('getStock', $params);
      foreach($request->data as $value) {
        if($value->type == 'resource-stocks') {
          return $value->id;
        }
      }
      $response = false;
    }
    catch(\Exception $e) {
      $response['error'] = $e->getMessage();
      $response['code'] = $e->getCode();
    }

    return $response;
  }

  /**
   * Build the block instance add form.
   *
   * @param string $reserved_for
   *   The dummy number and date client concatenated.
   *
   * @return array
   *   three reserved numbers.
   */
  public function reservationMsisdn($reserved_for) {
    $config = $this->config->get('transformation_act');
    $content_type = 'application/vnd.api+json';
    $numbers = FALSE;

    try {
      $body = [
        "data" => [
          "type" => "msisdn-reservations-create",
          "attributes" => [
            "reserved-for" => $reserved_for,
            "owned-by" => "",
            "number-type" => "voice",
            "limit" => 3
          ],
          "relationships" => [
            "stock" => [
              "data" => [
                "type" => "resource-stocks",
                "id" => $config['reservation']['stock_id']
              ]
            ]
          ]
        ]
      ];
      $params['body'] = json_encode($body);
      $params['headers']['Content-Type'] = $content_type;
      // MSISDN reservation.
      $reservation = $this->api->consumption('msisdnReservation', $params);
    }
    catch(\Exception $e) {
      $reservation['error'] = $e->getMessage();
      $reservation['code'] = $e->getCode();
    }
    if(!is_array($reservation)) {
      // Get reservated msisdn.
      try {
        unset($params);
        $params['tokens']['reservation_id'] = $reserved_for;
        $request = $this->api->consumption('getInfoByReservation', $params);
        $numbers = [];
        foreach($request->data as $value) {
          $numbers[] = $value->attributes->number;
        }
      \Drupal::logger('numbers reserved')->notice(print_r($numbers, 1));
      \Drupal::logger('ID reservation for creating')->notice(print_r($reserved_for, 1));
      }
      catch(\Exception $e) {
        $request['error'] = $e->getMessage();
        $request['code'] = $e->getCode();
      }
    }

    return $numbers;

  }

  /**
   *
   */
  public function updateReservation($reserved_for, $real_msisdn) {
    \Drupal::logger('ID reservation for updating')->notice(print_r($reserved_for, 1));
    \Drupal::logger('real_msisdn for updateReservation')->notice(print_r($real_msisdn, 1));

    $date = new \DateTime();
    $date->setTimeStamp(\Drupal::time()->getCurrentTime() + 300);
    $date->setTimeZone(new \DateTimeZone('America/Bogota'));
    $content_type = 'application/vnd.api+json';
    $status = FALSE;

    try {
      $body = [
        "data" => [
          "type" => "msisdn-reservations-update",
          "attributes" => [
            "reserved-for" => $reserved_for,
            "end-datetime" => $date->format('Y-m-d\TH:i:s-05:00') //"2018-10-01T18:01:37-05:00"
          ],
          "relationships" => [
            "msisdn" => [
              "data" => [
                "type" => "msisdns",
                "id" => $real_msisdn
              ]
            ]
          ]
        ]
      ];
      $params['body'] = json_encode($body);
      $params['headers']['Content-Type'] = $content_type;
      $request = $this->api->consumption('updateReservation', $params);
      $field = 'lifecycle-status';
      $status = $request->data->attributes->$field == 'completed'
      ? $real_msisdn : FALSE;
      \Drupal::logger('response updateReservation')->notice(print_r($status, 1));
    }
    catch(\Exception $e) {
      $request['error'] = $e->getMessage();
      $request['code'] = $e->getCode();
    }
    return $status;
  }

  /**
   *
   */
  public function iccid($msisdn) {
    try {
      $params['tokens']['msisdn'] = $msisdn;
      $request = $this->api->consumption('getIccid', $params);
      $field = 'lifecycle-status';
      if(!empty($request->data)) {
        if($request->data[0]->attributes->$field == 'in-use') {
          foreach($request->included as $value) {
            if($value->type == 'sim-cards') {
              $iccid = $value->id;
            }
          }
        }
        else {
          $iccid = false;
        \Drupal::logger('iccid is not in-use')->notice(print_r($iccid, 1));
        }
      }
      else {
        $iccid = false;
        \Drupal::logger('response iccid empty')->notice(print_r($iccid, 1));
      }

      $response = $iccid;
      \Drupal::logger('response iccid')->notice(print_r($response, 1));
    }
    catch(\Exception $e) {
      $response['error'] = $e->getMessage();
      $response['code'] = $e->getCode();
    }

    return $response;
  }

  /**
   *
   */
  public function activation(Array $data) {
    $store = $this->tempstore->get('transformation_activation');
    // Call service updateReservation, it returns a real msisdn
    $real_msisdn = $this->updateReservation($data['reserved_for'], $data['real_msisdn']);
    // Extra validation, which compares if it's the same
    // number selected by user as the return of the
    // updateReservation function.
    $real_msisdn =  ($data['real_msisdn'] == $real_msisdn) ? $real_msisdn : FALSE;
    $store->set('real_msisdn', $real_msisdn);
    $msisdn = isset($_COOKIE['Drupal_visitor_msisdn'])
    ? '57' . $_COOKIE['Drupal_visitor_msisdn'] : FALSE;
    // Call service getIccid, is necessary that the dummy
    // is well provisioning for returning numeric string ICCID.
    $iccid = $this->iccid($data['msisdn']);
    // Remove later.
    // $iccid = '8957732111175845150';
    $store->set('iccid', $iccid);
    // Get string numbers consuming a services called getProductId
    // but it's necessary first call getOrdersByAccountId service.
    $product_id = $this->getOrders('reference', $data['basket_id'], NULL, $data['account_id']);
    $store->set('product_id_reference', $product_id);
    $response = FALSE;

    if ($real_msisdn != FALSE
      && !is_array($data['reserved_for'])
      && $iccid != FALSE
      && !is_array($iccid)
      && $msisdn != FALSE
      && $product_id != FALSE
    ) {
      $body = [
        "data" => [
          "type" => "basket-products-update",
          "attributes" => [
            "inputted-characteristics" => [
              "CH_NumberResource" => $real_msisdn,
              "CH_ReservedFor" => $data['reserved_for'],
              "CH_ICC" => $iccid,
              "number-type" => "Numero Aleatorio",
              "CH_NumberOrigin" => $msisdn,
            ]
          ],
          "relationships" => [
            "instance" => [
              "data" => [
                "type" => "basket-products",
                "id" => $product_id,
              ]
            ]
          ]
        ]
      ];
      $params['body'] = json_encode($body);
      $params['headers']['Content-Type'] = 'application/vnd.api+json';
      try {
        $request = $this->api->consumption('updateBasket', $params);
        $field = 'lifecycle-status';
        $status = $request->data->attributes->$field == 'completed' ? TRUE : FALSE;
        \Drupal::logger('request updateBasket')->notice(print_r($body, 1));
        \Drupal::logger('response updateBasket')->notice(print_r($request, 1));
        \Drupal::logger('status updateBasket')->notice(print_r($status, 1));
      }
      catch(\Exception $e) {
        $request['error'] = $e->getMessage();
        $request['code'] = $e->getCode();
      }
      if (isset($status) && $status == TRUE) {
        try {
          $response = $this->submitBasket($data['basket_id']);
          \Drupal::logger('response submitBasket')->notice(print_r($response, 1));
        }
        catch (\Exception $e) {
          $response['error'] = $e->getMessage();
          $response['code'] = $e->getCode();
        }
        if (!is_array($response) && $response == TRUE) {
          drupal_set_message(Markup::create(
            '<div class="cardtigo cardtigo_shadow no-line">
              <em>Importante</em>
              <div class="msg-reload">¡Tu SIM se encuentra en proceso de activación!</div>
              <p>Recuerda <b>REINICIAR</b> el equipo para disfrutar de tus servicios.
              Al hacerlo recibirás un <b>SMS confirmando tu activación.</b></p>
            </div>'
          ), 'reload');
        }
        else {
          $store->set('error', 'No responde el servicio submitBasket');
          return $response;
        }
      }
      else {
        $store->set('error', 'No responde el servicio updateReservation');
        return $response;
      }
    }
    else {
      $store->set('error', 'No se completaron todos los valores');
      return $response;
    }

    return $response;
  }

  /**
   *
   */
  public function submitBasket($basket_id) {
    $body = [
      "data" => [
        "type" => "baskets-submit",
        "relationships" => [
          "instance" => [
            "data" => [
              "type" => "baskets",
              "id" => $basket_id
            ]
          ]
        ]
      ]
    ];
    $params['body'] = json_encode($body);
    $params['headers']['Content-Type'] = 'application/vnd.api+json';

    try {
      $request = $this->api->consumption('submitBasket', $params);
      \Drupal::logger('request submitBasket')->notice(print_r($body, 1));
      \Drupal::logger('response submitBasket')->notice(print_r($request, 1));
      $response = TRUE;
    }
    catch(\Exception $e) {
      $response['error'] = $e->getMessage();
      $response['code'] = $e->getCode();
    }

    return $response;
  }

}
