<?php
namespace Drupal\transformation_activation\Services;

use Drupal\tigoapi\TigoApi;
use Drupal\transformation_activation\Activation;

/**
 * Class TigoActivation
 * @package Drupal\transformation_activation\Services
 */
class TigoActivation {

  private $response = null;

  // TigoApi Object for service request's
  protected $api;


  /**
   * {@inheritdoc}
   */
  public function __construct(TigoApi $api) {
    $this->api = $api;
  }

  public function getResponse(){
    return $this->response;
  }

  /**
   * @param $data
   */
  public function activation($data) {

    $config = \Drupal::config('tigo_vtex_api.settings');
    $settings = $config->get('tigo_act_settings');
    $ids = str_replace('WSEC', '', $data['transactionId']);
    $ids = explode('P' , $ids);
    $query = db_select('vtex_orders', 'vo');
    $query->addField('vo', 'try');
    $query->addField('vo', 'ref_id');
    $query->condition('vo.sequence', $ids[0], '=');
    $query->condition('vo.product_id', $ids[1], '=');
    $query->leftJoin('vtex_orders_invoiced', 'vi', 'vo.order_id = vi.order_id');
    $query->addField('vi', 'imei');
    $result = $query->execute()->fetchObject();
    $count = 1;
    if($result && $result->try){
      $count =   $result->try + 1;
    }

    // Body request object
    $body = [
      "transactionId" => $data['transactionId'] . 'I' . $count, // orderID . "  "  .  sequence
      "customerDocument" => [
        "year" => (int) $data['year'],
        "docId" => (string) $data['docId'],
        "docType" => $data['docType'],
      ],
      "line" => [
        "imei" => isset($result->imei) 
          ? $result->imei 
          :"762173037834267",
        "imsi" => $data['imsi'],
        "msisdn" => '57' . $data['msisdn'],
      ],
      "saleType" => $this->saleType($result->ref_id),//cambai0,
      "seller" => [
        "sellerId" => !empty($settings['service']['sellerid']) 
			? $settings['service']['sellerid']
		  	: '1019083585',
        "sellerPassword" => !empty($settings['service']['sellerpass'])
			? $settings['service']['sellerpass']
			: '20184',
      ],
      "planId" => isset($data['moreData']['plan_id'])
          ? $data['moreData']['plan_id']
          : "1",
      "cellId" => 0,
      "notRenewal" => 0,
      "callback" => [
        "url" => !empty($settings['service']['callbackurl'])
            ? $settings['service']['callbackurl']
            : FALSE,
        "username" => !empty($settings['service']['callbackuser'])
			? $settings['service']['callbackuser']
			: FALSE,
        "password" => !empty($settings['service']['callbackpass'])
			? $settings['service']['callbackpass']
			: FALSE,
      ],
    ];

    // Build service parameters
    $params['body'] = json_encode($body);
    $params['headers'] = [
      'Authorization' => 'basic ' . base64_encode('ecommerce:3c0mm3rce.T1g0.2018'),
    ];

    // Service consumption
    try {
      $this->response = $this->api->consumption('activations', $params, TRUE, FALSE, FALSE);
      \Drupal::logger('response')->notice(print_r($this->response, 1));
    }
    catch(\Exception $e) {
      $this->response = $e;
      \Drupal::logger('exception')->error(print_r($e->getMessage(), 1));
    }
    return $this;
  }

  /**
   * @param $data
   * @return $this
   */
  public function packageActivation($msisdn) {

    $database = \Drupal::database()->select('vtex_orders', 'vo');
    $database->fields('vo', ['ref_id', 'sequence', 'product_id', 'client_email', 'description', 'try'])
      ->condition('msisdn', $msisdn);
    $data = $database->execute()->fetch();

    $transaction_id = $data->sequence . 'P' . $data->product_id;
    $config = \Drupal::config('tigo_vtex_api.settings')->get('tigo_act_settings')['options'];
    $package_id = (!empty($config['package_activation']) && $config['package_activation'] == 1)
      ? (String) $config['package_id']
      : $this->Sku($data->ref_id);

    $body = [
      'msisdn' => $msisdn,
      'packageId' => $package_id,
    ];

    $params = [
      'query' =>  [
        'type' => 'manager',
      ],
      'body' => json_encode($body),
      'headers' => [
        'platformId' => 'gestorTigoEcommerce',
        'transactionId' => $transaction_id,
        'UserTransaction' => $transaction_id,
      ]
    ];

    $log_data = [
        'package' => $package_id,
        'description' => $data->description,
        'msisdn' => $msisdn,
        'transacctionId' => $transaction_id,
    ];

    $log = [];

    sleep(20);

    try {
      $this->response = $this->api->consumption('vasProductSubscribe', $params, TRUE, TRUE, FALSE);
      $log['log'] = t('Activación de paquete exitosa.');
    }
    catch(\Exception $e) {
      $log_data['error_code'] = $e->getCode();
      $log_data['error_message'] = $e->getMessage();
      $log['log'] = t('Error al activar el paquete.');
    }

    $log['step']= 'Activación del paquete';
    $log['data'] = json_encode($log_data);

    Activation::queryInsertLog(date('Y-m-d H:i:s'), $data->sequence, $data->client_email, json_encode([$log]));
    return $this;
  }

  public function Sku($sku){
    $explode = explode('-', $sku);
    if(isset($explode[1])){
      $return = $explode[1];
    }else{
      $return = $sku;
    }
    return $return;
  }

  public function saleType($sku){
    $explode = explode('-', $sku);
    $return = 0;
    if(isset($explode[1])){
      switch ($explode[0]) {
        case 'KIT':
          $return = 1;
          break;
      }
    }
    return $return;
  }
}