<?php

namespace Drupal\transformation_activation\Step;

use Drupal\Core\Url;

/**
 * Class StepFinalize.
 *
 * @package Drupal\transformation_activation\Step
 */
class StepFinalize extends BaseStep {

  /**
   * {@inheritdoc}
   */
  protected function setStep() {
    return StepsEnum::STEP_FINALIZE;
  }

  /**
   * {@inheritdoc}
   */
  public function getButtons() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function buildStepFormElements() {
    if(isset($_SESSION['security_question_try']) 
    && is_numeric($_SESSION['security_question_try'])){
      $_SESSION['security_question_try'] = $_SESSION['security_question_try'] + 1;
    }else{
      $_SESSION['security_question_try'] = 1;
    }
    $_SESSION['security_question_0'] = FALSE;
    $_SESSION['security_question_1'] = FALSE;
    $_SESSION['security_question_2'] = FALSE;

    if($_SESSION['security_question_try'] < 2) {
      $query = db_select('transformation_activation_security_questions', 'sc');
      $query->addField('sc', 'id');
      $query->range(0,3);
      $query->orderRandom();
      $results = $query->execute()->fetchAll();
      $_SESSION['security_question'] = $results;
      $form['markup'] = [
        '#prefix' => '<div class="sorry-step notice-try-again content-shadow"><h2>¡Lo sentimos!</h2>',
        '#markup' => '<p>El proceso de validación no fue exitoso. Por favor inténte de nuevo.</p></div>'
      ];
      $form['retry'] = [
        '#type' => 'link',
        '#title' => 'Reintentar',
        '#attributes' => [
          'class' => ['btn-tigo btn-tigo--blue btn-tigo--tryagain']
        ],
        '#url' => Url::fromRoute(
          'transformation_activation.security_questions'
        ),
      ];
    }else{
      $info = $_SESSION['data_pospago'];
      if($info['moreData']['real_order_id']){
        $config = \Drupal::config('tigo_vtex_api.settings');
        $settings = $config->get('tigo_act_settings');
        $hours = isset($settings['service']['retry']) && is_numeric($settings['service']['retry'])
          ? $settings['service']['retry']
          : 24;
        $connection = \Drupal::database();
        $update = $connection->update('vtex_orders')
          ->fields([
              'date_retry' => format_date(strtotime("+". $hours ." hour"), 'custom', 'Y-m-d H:i:s')
          ])
          ->condition('order_id', $info['moreData']['real_order_id'])
          ->execute();
      }
      
      $form['markup'] = [
        '#prefix' => '<div class="sorry-step notice-warning content-shadow"><h2>¡Lo sentimos!</h2>',
        '#markup' => '<p>El proceso de validación no fue exitoso. Por favor ingresar al chat para brindarte ayuda.</p></div>'
      ];
      $_SESSION['step_log'] = FALSE;
      $_SESSION['data_pospago'] = FALSE;
      $_SESSION['security_question_0'] = FALSE;
      $_SESSION['security_question_1'] = FALSE;
      $_SESSION['security_question_2'] = FALSE;
      $_SESSION['security_question'] = FALSE;
      $_SESSION['identification_try'] = FALSE;
      $_SESSION['data_pospago'] = FALSE;
      $_SESSION['security_question_try'] = FALSE;
      user_cookie_delete('msisdn');
      user_cookie_delete('imsi');
      user_cookie_delete('client_email');
      user_cookie_delete('product_id');
      user_cookie_delete('date');
    }
    return $form;
  }

}
