<?php

namespace Drupal\transformation_activation;

use Drupal\Core\Url;
use Drupal\transformation_activation\OS;
use Drupal\transformation_activation\Activation;

require_once DRUPAL_ROOT . '/modules/custom/transformation_activation/src/os.php';

class ValidateActivation
{
    public static function buildValidate(){
        //Configuracion VtexConfigurationForm
        $config = \Drupal::config('tigo_vtex_api.settings');
        $tigo_act_settings = $config->get('tigo_act_settings');
        if(isset($tigo_act_settings['options']['maintenance_mode'])
            && $tigo_act_settings['options']['maintenance_mode'] > time()
        ){
            $output = [
                '#theme' => 'maintenance-mode',
                '#attached' => [
                    'library' => ['transformation_activation/transformation_activation']
                ]
            ];
            $output = self::_hsq($output);
            return $output;
        }

        $numberPhone = isset($_COOKIE['Drupal_visitor_msisdn'])
            ? $_COOKIE['Drupal_visitor_msisdn']
            : FALSE;
        if ($tigo_act_settings['options']['detect_device'] == 1 && !OS::isMobil()) {
            //Detect mobile device, if device is not mobile, make a redirect to informative page
            //Si no tiene protocolo
            $final_url = "";
            $http = 'http://';
            $url = $tigo_act_settings['desktop_url'];
            $protocol = explode(':',$url);
            if ($protocol[0] == 'http' || $protocol[0] == 'https') {
                $final_url = $url;
            }else {
                $final_url = $http.$url;
            }
            header('Location: '.$final_url); //tigo-activation/desktop-device
            exit;
        }elseif($numberPhone == '' && $tigo_act_settings['options']['validate_number'] == 1) {
            return self::NotPhone();
        }

        try {
          $tigoNumber = Activation::validateTigoNumber(Activation::clearNumber($numberPhone));
        }
        catch(\Exception $e) {
          $tigoNumber = FALSE;
        }

        if ($tigoNumber && $tigoNumber->account->status === 'ACTIVE') {
            $output['#attached']['library'][] = 'transformation_activation/transformation_activation';
            $output['container'] = array(
                '#type' => 'container',
                '#attributes' => array(
                    'class' => array('sim-active'),
                ),
            );
            $output['container']['cardtigo'] = array(
                '#type' => 'container',
                '#attributes' => array(
                    'class' => array(
                        'cardtigo',
                        'cardtigo_shadow',
                        'no-line'
                    ),
                ),
            );
            $output['container']['cardtigo']['markup'] = [
                '#markup' => "<h5>!Tu SIM se encuentra activa!</h5><p>Si tu equipo es <b>doble SIM</b>, asegúrate que los datos móviles y SMS correspondan a tu SIM Tigo, si tienes dudas puedes consultar <a href='/servicios/activate/ten-en-cuenta'>aquí</a></p>"

            ];

            $MyAccountData = [
                'type' => 'sim-active',
                'title' => 'Ahora Consulta tu línea y tus servicios con Mi cuenta TIGO',
                'items' => [
                    'consumption' => [
                        'markup' => 'Consulta tu consumo',
                        'class' => 'account-consumption'
                    ],
                    'balance' => [
                        'markup' => 'Consulta tu saldo',
                        'class' => 'account-balance'
                    ],
                    'chat' => [
                        'markup' => 'Chat en línea',
                        'class' => 'account-chat'
                    ]
                ],
                'button' => 'Ir a mi cuenta'
            ];


            $output = self::MyAccount($MyAccountData, $output);
            $output['account']['#prefix'] = '<div class="my-account">';
            $output['account']['#suffix'] = '</div>';
            $output = self::_hsq($output);
            return $output;
        }
    }

    public static function validateMail(){
        if(!isset($_COOKIE['Drupal_visitor_client_email']) || !isset($_COOKIE['Drupal_visitor_msisdn'])){
            if(isset($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['SERVER_NAME']){
                $base_url = $_SERVER['HTTP_X_FORWARDED_PROTO'] . '://' . $_SERVER['SERVER_NAME'];
            }else{
                global $base_url;
            }
            header('Location: '.$base_url . '/servicios/activate');
            exit;
        }
    }

    public static function NotPhone(){

        if(!isset($_COOKIE["activation_try"])){
            setcookie("activation_try",1,time()+(60*5));
            //setcookie("name","algo",time()+1440);
            $output['#attached']['library'][] = 'transformation_activation/transformation_activation';
            $output['container'] = array(
                '#type' => 'container',
                '#attributes' => array(
                    'class' => array('number-not-found'),
                ),
            );
            // $output['container']['title'] = [
            //     '#markup' => "<h5>ACTIVA TU SIM</h5>"
            // ];
            $output['container']['cardtigo'] = array(
                '#type' => 'container',
                '#attributes' => array(
                    'class' => array('cardtigo'),
                ),
            );
            $output['container']['cardtigo']['title'] = [
                '#markup' => "<h2>NO IDENTIFICAMOS LA LÍNEA</h2>"
            ];
            $output['container']['cardtigo']['subtitle'] = [
                '#markup' => "<h3>No hemos identificado tu número de linea por favor verifica que:</h3>"
            ];
            $output['container']['cardtigo']['items'] = [
                '#theme' => 'item_list',
                '#items' => [
                    [
                        '#markup' => 'La <b>SIM</b> se encuentre en la <b>posición correcta</b>.'
                    ],
                    [
                        '#markup' => 'La opción de <b>modo avión</b> y <b>Wifi</b> esté desactivada.'
                    ],
                    [
                        '#markup' => 'Los datos móviles estén en <b>modo activo</b>.'
                    ],
                    [
                        '#markup' => 'Si tienes dos <b>SIM</b> en tu equipo retira la que tienes en uso y conserva únicamente la <b>SIM Tigo</b> que quieres activar.'
                    ]
                ]
            ];
            $output['container']['cardtigo']['link'] = [
                '#type' => 'link',
                '#title' => 'Reintentar',
                '#url' => Url::fromRoute(
                    'transformation_activation.activate_sim'
                )
            ];
        }else{
            //setcookie("name","algo",time()+1440);
            $output['#attached']['library'][] = 'transformation_activation/transformation_activation';
            $output['container'] = array(
                '#type' => 'container',
                '#attributes' => array(
                    'class' => array('number-not-found'),
                ),
            );
            // $output['container']['title'] = [
            //     '#markup' => "<h5>ACTIVA TU SIM</h5>"
            // ];
            $output['container']['cardtigo'] = array(
                '#type' => 'container',
                '#attributes' => array(
                    'class' => array('cardtigo'),
                ),
            );
            $output['container']['cardtigo']['title'] = [
                '#markup' => "<h2>SIM NO ACTIVADA</h2>"
            ];
            $output['container']['cardtigo']['subtitle'] = [
                '#markup' => "<h3><b>Lo sentimos</b>, tu SIM Tigo no pudo ser activada</h3>"
            ];
            $output['container']['cardtigo']['items'] = [
                '#markup' => '<p>Por favor ingresa al <b>chat en línea</b> para que un asesor te oriente en el proceso</p>'
            ];
            $output['container']['cardtigo']['link'] = [
                '#type' => 'link',
                '#title' => 'CHAT EN LÍNEA',
                '#url' => Url::fromUri('https://www.tigo.com.co/chat'),
                '#attributes' => [
                    'target' => '_blank'
                ]
            ];
        }
        $output = self::_hsq($output);
        return $output;
    }
    public static function MyAccount($data, $output = NULL){
        $output['account'] = array(
            '#type' => 'container',
            '#attributes' => array(
                'class' => array('cardtigo', 'cardtigo_shadow', 'no-line'),
            ),
        );
        $output['account']['title'] = array(
            '#markup' => '<h3>'. $data['title'] .'</h3>'
        );
        if($data['type'] == 'sim-active'){
            $output['account']['markup'] = array(
                '#markup' => '<p>Desde tu móvil, tablet o computador</p>'
            );
        }
        foreach ($data['items'] as $key => $value){
            $items[] = [
                'data' => [
                    '#type' => 'markup',
                    '#markup' => $value['markup']
                ],
                '#wrapper_attributes' => [
                    'class' => $value['class'],
                ]
            ];
        }
        $output['account']['items'] = [
            '#theme' => 'item_list',
            '#items' => $items
        ];
        if($data['type'] == 'sim-details'){
            $output['account']['markup1'] = array(
                '#markup' => '<p>Ingresa a Mi cuenta, administra estos y otros servicios</p>'
            );
        }
        $output['account']['link'] = [
            '#type' => 'link',
            '#title' => $data['button'],
            '#url' => Url::fromUri('https://micuenta.tigo.com.co/'),
            '#attributes' => [
                'target' => '_blank'
            ]
        ];
        $output = self::_hsq($output);
        return $output;
    }
    public static function _hsq($output){
        $output['#attached']['html_head'][] = [
            // The data.
            [
                '#type' => 'html_tag',
                '#tag' => 'script',
                '#value' => 'var idEvent = "000006005135"; var _hsq = window._hsq = window._hsq || []; _hsq.push(["trackEvent", {id: idEvent }]);'
            ],
            '_hsq'
        ];

        $output['#attached']['html_head'][] = [
            // The data.
            [
                '#type' => 'html_tag',
                // The HTML tag to add, in this case a  tag.
                '#tag' => 'script',
                // Set attributes like src to load a file.
                '#attributes' => [
                    'type' => 'text/javascript',
                    'id' => 'hs-script-loader',
                    'async' => TRUE,
                    'defer' => TRUE,
                    'src' => '//js.hs-scripts.com/2638078.js'
                ]
            ],
            'js-hs'
        ];
        return $output;
    }

    public static function GetTypeDocument($output) {
        switch ($output) {
            case 'CC':
                $response = '1';
            break;
            case 'CE':
                $response = '4';
            break;
        }
        return $response;
    }


    public static function FormatNumber($value, $prefix=FALSE) {

        if (isset($prefix) && $prefix == '57') {
            $value = substr(trim($value), 2);
        }
        $pattern = '/([0-9]{3})([0-9]{3})([0-9]{4})/i';
        $substitute = '($1) $2-$3';
        $number = preg_replace($pattern, $substitute, $value);

        return $number;

    }


}
